# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: data-node/api/v2/trading_data.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....vega import vega_pb2 as vega_dot_vega__pb2
from ....vega import governance_pb2 as vega_dot_governance__pb2
from ....vega import markets_pb2 as vega_dot_markets__pb2
from ....vega import assets_pb2 as vega_dot_assets__pb2
from ....vega import oracle_pb2 as vega_dot_oracle__pb2
from ....vega.events.v1 import events_pb2 as vega_dot_events_dot_v1_dot_events__pb2
from ....vega.commands.v1 import (
    validator_commands_pb2 as vega_dot_commands_dot_v1_dot_validator__commands__pb2,
)
from protoc_gen_openapiv2.options import (
    annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2,
)


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n#data-node/api/v2/trading_data.proto\x12\x0f\x64\x61tanode.api.v2\x1a\x0fvega/vega.proto\x1a\x15vega/governance.proto\x1a\x12vega/markets.proto\x1a\x11vega/assets.proto\x1a\x11vega/oracle.proto\x1a\x1bvega/events/v1/events.proto\x1a)vega/commands/v1/validator_commands.proto\x1a.protoc-gen-openapiv2/options/annotations.proto"\\\n\x10OffsetPagination\x12\x12\n\x04skip\x18\x01 \x01(\x04R\x04skip\x12\x14\n\x05limit\x18\x02 \x01(\x04R\x05limit\x12\x1e\n\ndescending\x18\x03 \x01(\x08R\ndescending"\xd9\x01\n\nPagination\x12\x19\n\x05\x66irst\x18\x01 \x01(\x05H\x00R\x05\x66irst\x88\x01\x01\x12\x19\n\x05\x61\x66ter\x18\x02 \x01(\tH\x01R\x05\x61\x66ter\x88\x01\x01\x12\x17\n\x04last\x18\x03 \x01(\x05H\x02R\x04last\x88\x01\x01\x12\x1b\n\x06\x62\x65\x66ore\x18\x04 \x01(\tH\x03R\x06\x62\x65\x66ore\x88\x01\x01\x12&\n\x0cnewest_first\x18\x05 \x01(\x08H\x04R\x0bnewestFirst\x88\x01\x01\x42\x08\n\x06_firstB\x08\n\x06_afterB\x07\n\x05_lastB\t\n\x07_beforeB\x0f\n\r_newest_first"\x9c\x01\n\x08PageInfo\x12"\n\rhas_next_page\x18\x01 \x01(\x08R\x0bhasNextPage\x12*\n\x11has_previous_page\x18\x02 \x01(\x08R\x0fhasPreviousPage\x12!\n\x0cstart_cursor\x18\x03 \x01(\tR\x0bstartCursor\x12\x1d\n\nend_cursor\x18\x04 \x01(\tR\tendCursor"\x9a\x01\n\x0e\x41\x63\x63ountBalance\x12\x14\n\x05owner\x18\x02 \x01(\tR\x05owner\x12\x18\n\x07\x62\x61lance\x18\x03 \x01(\tR\x07\x62\x61lance\x12\x14\n\x05\x61sset\x18\x04 \x01(\tR\x05\x61sset\x12\x1b\n\tmarket_id\x18\x05 \x01(\tR\x08marketId\x12%\n\x04type\x18\x06 \x01(\x0e\x32\x11.vega.AccountTypeR\x04type"\x9e\x01\n\x13ListAccountsRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x06\x66ilter\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"W\n\x14ListAccountsResponse\x12?\n\x08\x61\x63\x63ounts\x18\x01 \x01(\x0b\x32#.datanode.api.v2.AccountsConnectionR\x08\x61\x63\x63ounts"\x80\x01\n\x12\x41\x63\x63ountsConnection\x12\x32\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1c.datanode.api.v2.AccountEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"`\n\x0b\x41\x63\x63ountEdge\x12\x39\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x07\x61\x63\x63ount\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8d\x01\n\x16ObserveAccountsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x14\n\x05\x61sset\x18\x03 \x01(\tR\x05\x61sset\x12%\n\x04type\x18\x04 \x01(\x0e\x32\x11.vega.AccountTypeR\x04type"\xa6\x01\n\x17ObserveAccountsResponse\x12\x42\n\x08snapshot\x18\x01 \x01(\x0b\x32$.datanode.api.v2.AccountSnapshotPageH\x00R\x08snapshot\x12;\n\x07updates\x18\x02 \x01(\x0b\x32\x1f.datanode.api.v2.AccountUpdatesH\x00R\x07updatesB\n\n\x08response"o\n\x13\x41\x63\x63ountSnapshotPage\x12;\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x08\x61\x63\x63ounts\x12\x1b\n\tlast_page\x18\x02 \x01(\x08R\x08lastPage"M\n\x0e\x41\x63\x63ountUpdates\x12;\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.AccountBalanceR\x08\x61\x63\x63ounts"\r\n\x0bInfoRequest"I\n\x0cInfoResponse\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x1f\n\x0b\x63ommit_hash\x18\x02 \x01(\tR\ncommitHash"W\n\x0fGetOrderRequest\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12\x1d\n\x07version\x18\x02 \x01(\x05H\x00R\x07version\x88\x01\x01\x42\n\n\x08_version"5\n\x10GetOrderResponse\x12!\n\x05order\x18\x01 \x01(\x0b\x32\x0b.vega.OrderR\x05order"\xf1\x02\n\x11ListOrdersRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12 \n\tmarket_id\x18\x02 \x01(\tH\x01R\x08marketId\x88\x01\x01\x12!\n\treference\x18\x03 \x01(\tH\x02R\treference\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x03R\npagination\x88\x01\x01\x12 \n\tlive_only\x18\x05 \x01(\x08H\x04R\x08liveOnly\x88\x01\x01\x12>\n\ndate_range\x18\x06 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x05R\tdateRange\x88\x01\x01\x42\x0b\n\t_party_idB\x0c\n\n_market_idB\x0c\n\n_referenceB\r\n\x0b_paginationB\x0c\n\n_live_onlyB\r\n\x0b_date_range"N\n\x12ListOrdersResponse\x12\x38\n\x06orders\x18\x01 \x01(\x0b\x32 .datanode.api.v2.OrderConnectionR\x06orders"\x86\x01\n\x18ListOrderVersionsRequest\x12\x19\n\x08order_id\x18\x01 \x01(\tR\x07orderId\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"U\n\x19ListOrderVersionsResponse\x12\x38\n\x06orders\x18\x01 \x01(\x0b\x32 .datanode.api.v2.OrderConnectionR\x06orders"s\n\x14ObserveOrdersRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_party_id"\xa0\x01\n\x15ObserveOrdersResponse\x12@\n\x08snapshot\x18\x01 \x01(\x0b\x32".datanode.api.v2.OrderSnapshotPageH\x00R\x08snapshot\x12\x39\n\x07updates\x18\x02 \x01(\x0b\x32\x1d.datanode.api.v2.OrderUpdatesH\x00R\x07updatesB\n\n\x08response"U\n\x11OrderSnapshotPage\x12#\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.OrderR\x06orders\x12\x1b\n\tlast_page\x18\x02 \x01(\x08R\x08lastPage"3\n\x0cOrderUpdates\x12#\n\x06orders\x18\x01 \x03(\x0b\x32\x0b.vega.OrderR\x06orders"\x9f\x01\n\x14ListPositionsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"Z\n\x15ListPositionsResponse\x12\x41\n\tpositions\x18\x01 \x01(\x0b\x32#.datanode.api.v2.PositionConnectionR\tpositions"J\n\x0cPositionEdge\x12"\n\x04node\x18\x01 \x01(\x0b\x32\x0e.vega.PositionR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n\x12PositionConnection\x12\x33\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1d.datanode.api.v2.PositionEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"v\n\x17ObservePositionsRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12 \n\tmarket_id\x18\x02 \x01(\tH\x01R\x08marketId\x88\x01\x01\x42\x0b\n\t_party_idB\x0c\n\n_market_id"\xa9\x01\n\x18ObservePositionsResponse\x12\x43\n\x08snapshot\x18\x01 \x01(\x0b\x32%.datanode.api.v2.PositionSnapshotPageH\x00R\x08snapshot\x12<\n\x07updates\x18\x02 \x01(\x0b\x32 .datanode.api.v2.PositionUpdatesH\x00R\x07updatesB\n\n\x08response"a\n\x14PositionSnapshotPage\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x0e.vega.PositionR\tpositions\x12\x1b\n\tlast_page\x18\x02 \x01(\x08R\x08lastPage"?\n\x0fPositionUpdates\x12,\n\tpositions\x18\x01 \x03(\x0b\x32\x0e.vega.PositionR\tpositions"\xa3\x02\n\x11LedgerEntryFilter\x12\x37\n\x18\x63lose_on_account_filters\x18\x01 \x01(\x08R\x15\x63loseOnAccountFilters\x12N\n\x13\x61\x63\x63ount_from_filter\x18\x02 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x11\x61\x63\x63ountFromFilter\x12J\n\x11\x61\x63\x63ount_to_filter\x18\x03 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x0f\x61\x63\x63ountToFilter\x12\x39\n\x0etransfer_types\x18\x05 \x03(\x0e\x32\x12.vega.TransferTypeR\rtransferTypes"\xd2\x02\n\x17\x41ggregatedLedgerEntries\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x1a\n\x08quantity\x18\x03 \x01(\tR\x08quantity\x12\x1e\n\x08party_id\x18\x04 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1e\n\x08\x61sset_id\x18\x05 \x01(\tH\x01R\x07\x61ssetId\x88\x01\x01\x12 \n\tmarket_id\x18\x06 \x01(\tH\x02R\x08marketId\x88\x01\x01\x12\x37\n\rtransfer_type\x18\x07 \x01(\x0e\x32\x12.vega.TransferTypeR\x0ctransferType\x12\x34\n\x0c\x61\x63\x63ount_type\x18\x08 \x01(\x0e\x32\x11.vega.AccountTypeR\x0b\x61\x63\x63ountTypeB\x0b\n\t_party_idB\x0b\n\t_asset_idB\x0c\n\n_market_idJ\x04\x08\x01\x10\x02"\xad\x01\n\x0cGroupOptions\x12G\n\x10\x62y_account_field\x18\x01 \x03(\x0e\x32\x1d.datanode.api.v2.AccountFieldR\x0e\x62yAccountField\x12T\n\x15\x62y_ledger_entry_field\x18\x02 \x03(\x0e\x32!.datanode.api.v2.LedgerEntryFieldR\x12\x62yLedgerEntryField"\xba\x02\n\x18ListLedgerEntriesRequest\x12:\n\x06\x66ilter\x18\x01 \x01(\x0b\x32".datanode.api.v2.LedgerEntryFilterR\x06\x66ilter\x12\x42\n\rgroup_options\x18\x02 \x01(\x0b\x32\x1d.datanode.api.v2.GroupOptionsR\x0cgroupOptions\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x04 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"v\n\x19ListLedgerEntriesResponse\x12Y\n\x0eledger_entries\x18\x01 \x01(\x0b\x32\x32.datanode.api.v2.AggregatedLedgerEntriesConnectionR\rledgerEntries"s\n\x1b\x41ggregatedLedgerEntriesEdge\x12<\n\x04node\x18\x01 \x01(\x0b\x32(.datanode.api.v2.AggregatedLedgerEntriesR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x9f\x01\n!AggregatedLedgerEntriesConnection\x12\x42\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32,.datanode.api.v2.AggregatedLedgerEntriesEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xf3\x01\n\x19ListBalanceChangesRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x06\x66ilter\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x06 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"f\n\x1aListBalanceChangesResponse\x12H\n\x08\x62\x61lances\x18\x01 \x01(\x0b\x32,.datanode.api.v2.AggregatedBalanceConnectionR\x08\x62\x61lances"\xac\x02\n\x18GetBalanceHistoryRequest\x12\x36\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x1e.datanode.api.v2.AccountFilterR\x06\x66ilter\x12\x38\n\x08group_by\x18\x02 \x03(\x0e\x32\x1d.datanode.api.v2.AccountFieldR\x07groupBy\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x04 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"e\n\x19GetBalanceHistoryResponse\x12H\n\x08\x62\x61lances\x18\x01 \x01(\x0b\x32,.datanode.api.v2.AggregatedBalanceConnectionR\x08\x62\x61lances"g\n\x15\x41ggregatedBalanceEdge\x12\x36\n\x04node\x18\x01 \x01(\x0b\x32".datanode.api.v2.AggregatedBalanceR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x93\x01\n\x1b\x41ggregatedBalanceConnection\x12<\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32&.datanode.api.v2.AggregatedBalanceEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x9e\x01\n\rAccountFilter\x12\x19\n\x08\x61sset_id\x18\x01 \x01(\tR\x07\x61ssetId\x12\x1b\n\tparty_ids\x18\x02 \x03(\tR\x08partyIds\x12\x1d\n\nmarket_ids\x18\x03 \x03(\tR\tmarketIds\x12\x36\n\raccount_types\x18\x04 \x03(\x0e\x32\x11.vega.AccountTypeR\x0c\x61\x63\x63ountTypes"\xa1\x02\n\x11\x41ggregatedBalance\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\x12\x18\n\x07\x62\x61lance\x18\x02 \x01(\tR\x07\x62\x61lance\x12\x1e\n\x08party_id\x18\x04 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1e\n\x08\x61sset_id\x18\x05 \x01(\tH\x01R\x07\x61ssetId\x88\x01\x01\x12 \n\tmarket_id\x18\x06 \x01(\tH\x02R\x08marketId\x88\x01\x01\x12\x39\n\x0c\x61\x63\x63ount_type\x18\x07 \x01(\x0e\x32\x11.vega.AccountTypeH\x03R\x0b\x61\x63\x63ountType\x88\x01\x01\x42\x0b\n\t_party_idB\x0b\n\t_asset_idB\x0c\n\n_market_idB\x0f\n\r_account_type";\n\x1aObserveMarketsDepthRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds"S\n\x1bObserveMarketsDepthResponse\x12\x34\n\x0cmarket_depth\x18\x01 \x03(\x0b\x32\x11.vega.MarketDepthR\x0bmarketDepth"B\n!ObserveMarketsDepthUpdatesRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds"U\n"ObserveMarketsDepthUpdatesResponse\x12/\n\x06update\x18\x01 \x03(\x0b\x32\x17.vega.MarketDepthUpdateR\x06update":\n\x19ObserveMarketsDataRequest\x12\x1d\n\nmarket_ids\x18\x01 \x03(\tR\tmarketIds"O\n\x1aObserveMarketsDataResponse\x12\x31\n\x0bmarket_data\x18\x01 \x03(\x0b\x32\x10.vega.MarketDataR\nmarketData"j\n\x1bGetLatestMarketDepthRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12 \n\tmax_depth\x18\x02 \x01(\x04H\x00R\x08maxDepth\x88\x01\x01\x42\x0c\n\n_max_depth"\xda\x01\n\x1cGetLatestMarketDepthResponse\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12"\n\x03\x62uy\x18\x02 \x03(\x0b\x32\x10.vega.PriceLevelR\x03\x62uy\x12$\n\x04sell\x18\x03 \x03(\x0b\x32\x10.vega.PriceLevelR\x04sell\x12*\n\nlast_trade\x18\x04 \x01(\x0b\x32\x0b.vega.TradeR\tlastTrade\x12\'\n\x0fsequence_number\x18\x05 \x01(\x04R\x0esequenceNumber"\x1d\n\x1bListLatestMarketDataRequest"S\n\x1cListLatestMarketDataResponse\x12\x33\n\x0cmarkets_data\x18\x01 \x03(\x0b\x32\x10.vega.MarketDataR\x0bmarketsData"9\n\x1aGetLatestMarketDataRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId"P\n\x1bGetLatestMarketDataResponse\x12\x31\n\x0bmarket_data\x18\x01 \x01(\x0b\x32\x10.vega.MarketDataR\nmarketData"\xfc\x02\n\x1fGetMarketDataHistoryByIDRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12,\n\x0fstart_timestamp\x18\x02 \x01(\x03H\x00R\x0estartTimestamp\x88\x01\x01\x12(\n\rend_timestamp\x18\x03 \x01(\x03H\x01R\x0c\x65ndTimestamp\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x12W\n\x11offset_pagination\x18\x05 \x01(\x0b\x32!.datanode.api.v2.OffsetPaginationB\x02\x18\x01H\x03R\x10offsetPagination\x88\x01\x01\x42\x12\n\x10_start_timestampB\x10\n\x0e_end_timestampB\r\n\x0b_paginationB\x14\n\x12_offset_pagination"j\n GetMarketDataHistoryByIDResponse\x12\x46\n\x0bmarket_data\x18\x01 \x01(\x0b\x32%.datanode.api.v2.MarketDataConnectionR\nmarketData"N\n\x0eMarketDataEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.MarketDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x85\x01\n\x14MarketDataConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.MarketDataEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo":\n\x1bMarketsDataSubscribeRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId"Q\n\x1cMarketsDataSubscribeResponse\x12\x31\n\x0bmarket_data\x18\x01 \x03(\x0b\x32\x10.vega.MarketDataR\nmarketData"\xd1\x01\n\x14ListTransfersRequest\x12\x1b\n\x06pubkey\x18\x01 \x01(\tH\x00R\x06pubkey\x88\x01\x01\x12@\n\tdirection\x18\x02 \x01(\x0e\x32".datanode.api.v2.TransferDirectionR\tdirection\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\t\n\x07_pubkeyB\r\n\x0b_pagination"Z\n\x15ListTransfersResponse\x12\x41\n\ttransfers\x18\x01 \x01(\x0b\x32#.datanode.api.v2.TransferConnectionR\ttransfers"T\n\x0cTransferEdge\x12,\n\x04node\x18\x01 \x01(\x0b\x32\x18.vega.events.v1.TransferR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n\x12TransferConnection\x12\x33\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1d.datanode.api.v2.TransferEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x19\n\x17GetNetworkLimitsRequest"G\n\x18GetNetworkLimitsResponse\x12+\n\x06limits\x18\x01 \x01(\x0b\x32\x13.vega.NetworkLimitsR\x06limits"9\n\x1aListCandleIntervalsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId"M\n\x12IntervalToCandleId\x12\x1a\n\x08interval\x18\x01 \x01(\tR\x08interval\x12\x1b\n\tcandle_id\x18\x02 \x01(\tR\x08\x63\x61ndleId"u\n\x1bListCandleIntervalsResponse\x12V\n\x15interval_to_candle_id\x18\x01 \x03(\x0b\x32#.datanode.api.v2.IntervalToCandleIdR\x12intervalToCandleId"\xa7\x01\n\x06\x43\x61ndle\x12\x14\n\x05start\x18\x01 \x01(\x03R\x05start\x12\x1f\n\x0blast_update\x18\x02 \x01(\x03R\nlastUpdate\x12\x12\n\x04high\x18\x03 \x01(\tR\x04high\x12\x10\n\x03low\x18\x04 \x01(\tR\x03low\x12\x12\n\x04open\x18\x05 \x01(\tR\x04open\x12\x14\n\x05\x63lose\x18\x06 \x01(\tR\x05\x63lose\x12\x16\n\x06volume\x18\x07 \x01(\x04R\x06volume"7\n\x18ObserveCandleDataRequest\x12\x1b\n\tcandle_id\x18\x01 \x01(\tR\x08\x63\x61ndleId"L\n\x19ObserveCandleDataResponse\x12/\n\x06\x63\x61ndle\x18\x01 \x01(\x0b\x32\x17.datanode.api.v2.CandleR\x06\x63\x61ndle"\xfb\x01\n\x15ListCandleDataRequest\x12\x1b\n\tcandle_id\x18\x01 \x01(\tR\x08\x63\x61ndleId\x12%\n\x0e\x66rom_timestamp\x18\x02 \x01(\x03R\rfromTimestamp\x12!\n\x0cto_timestamp\x18\x03 \x01(\x03R\x0btoTimestamp\x12*\n\x08interval\x18\x04 \x01(\x0e\x32\x0e.vega.IntervalR\x08interval\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"Y\n\x16ListCandleDataResponse\x12?\n\x07\x63\x61ndles\x18\x01 \x01(\x0b\x32%.datanode.api.v2.CandleDataConnectionR\x07\x63\x61ndles"Q\n\nCandleEdge\x12+\n\x04node\x18\x01 \x01(\x0b\x32\x17.datanode.api.v2.CandleR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n\x14\x43\x61ndleDataConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.CandleEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xc6\x01\n\x10ListVotesRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12$\n\x0bproposal_id\x18\x02 \x01(\tH\x01R\nproposalId\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\x0b\n\t_party_idB\x0e\n\x0c_proposal_idB\r\n\x0b_pagination"J\n\x11ListVotesResponse\x12\x35\n\x05votes\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.VoteConnectionR\x05votes"B\n\x08VoteEdge\x12\x1e\n\x04node\x18\x01 \x01(\x0b\x32\n.vega.VoteR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"y\n\x0eVoteConnection\x12/\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x19.datanode.api.v2.VoteEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"x\n\x13ObserveVotesRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12$\n\x0bproposal_id\x18\x02 \x01(\tH\x01R\nproposalId\x88\x01\x01\x42\x0b\n\t_party_idB\x0e\n\x0c_proposal_id"6\n\x14ObserveVotesResponse\x12\x1e\n\x04vote\x18\x01 \x01(\x0b\x32\n.vega.VoteR\x04vote"\xbd\x01\n*ListERC20MultiSigSignerAddedBundlesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x1b\n\tepoch_seq\x18\x03 \x01(\tR\x08\x65pochSeq\x12;\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"|\n+ListERC20MultiSigSignerAddedBundlesResponse\x12M\n\x07\x62undles\x18\x01 \x01(\x0b\x32\x33.datanode.api.v2.ERC20MultiSigSignerAddedConnectionR\x07\x62undles"t\n\x1c\x45RC20MultiSigSignerAddedEdge\x12<\n\x04node\x18\x01 \x01(\x0b\x32(.vega.events.v1.ERC20MultiSigSignerAddedR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x81\x01\n"ERC20MultiSigSignerAddedBundleEdge\x12\x43\n\x04node\x18\x01 \x01(\x0b\x32/.datanode.api.v2.ERC20MultiSigSignerAddedBundleR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\xa7\x01\n"ERC20MultiSigSignerAddedConnection\x12I\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x33.datanode.api.v2.ERC20MultiSigSignerAddedBundleEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xce\x01\n\x1e\x45RC20MultiSigSignerAddedBundle\x12\x1d\n\nnew_signer\x18\x01 \x01(\tR\tnewSigner\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x14\n\x05nonce\x18\x04 \x01(\tR\x05nonce\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x1e\n\nsignatures\x18\x06 \x01(\tR\nsignatures\x12\x1b\n\tepoch_seq\x18\x03 \x01(\tR\x08\x65pochSeq"\xbf\x01\n,ListERC20MultiSigSignerRemovedBundlesRequest\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x1b\n\tepoch_seq\x18\x03 \x01(\tR\x08\x65pochSeq\x12;\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"\x80\x01\n-ListERC20MultiSigSignerRemovedBundlesResponse\x12O\n\x07\x62undles\x18\x01 \x01(\x0b\x32\x35.datanode.api.v2.ERC20MultiSigSignerRemovedConnectionR\x07\x62undles"x\n\x1e\x45RC20MultiSigSignerRemovedEdge\x12>\n\x04node\x18\x01 \x01(\x0b\x32*.vega.events.v1.ERC20MultiSigSignerRemovedR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x85\x01\n$ERC20MultiSigSignerRemovedBundleEdge\x12\x45\n\x04node\x18\x01 \x01(\x0b\x32\x31.datanode.api.v2.ERC20MultiSigSignerRemovedBundleR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\xab\x01\n$ERC20MultiSigSignerRemovedConnection\x12K\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x35.datanode.api.v2.ERC20MultiSigSignerRemovedBundleEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xd0\x01\n ERC20MultiSigSignerRemovedBundle\x12\x1d\n\nold_signer\x18\x01 \x01(\tR\toldSigner\x12\x1c\n\tsubmitter\x18\x02 \x01(\tR\tsubmitter\x12\x14\n\x05nonce\x18\x04 \x01(\tR\x05nonce\x12\x1c\n\ttimestamp\x18\x05 \x01(\x03R\ttimestamp\x12\x1e\n\nsignatures\x18\x06 \x01(\tR\nsignatures\x12\x1b\n\tepoch_seq\x18\x07 \x01(\tR\x08\x65pochSeq";\n\x1eGetERC20ListAssetBundleRequest\x12\x19\n\x08\x61sset_id\x18\x01 \x01(\tR\x07\x61ssetId"\x9e\x01\n\x1fGetERC20ListAssetBundleResponse\x12!\n\x0c\x61sset_source\x18\x01 \x01(\tR\x0b\x61ssetSource\x12"\n\rvega_asset_id\x18\x02 \x01(\tR\x0bvegaAssetId\x12\x14\n\x05nonce\x18\x03 \x01(\tR\x05nonce\x12\x1e\n\nsignatures\x18\x04 \x01(\tR\nsignatures"F\n#GetERC20SetAssetLimitsBundleRequest\x12\x1f\n\x0bproposal_id\x18\x01 \x01(\tR\nproposalId"\xe8\x01\n$GetERC20SetAssetLimitsBundleResponse\x12!\n\x0c\x61sset_source\x18\x01 \x01(\tR\x0b\x61ssetSource\x12"\n\rvega_asset_id\x18\x02 \x01(\tR\x0bvegaAssetId\x12\x14\n\x05nonce\x18\x03 \x01(\tR\x05nonce\x12%\n\x0elifetime_limit\x18\x04 \x01(\tR\rlifetimeLimit\x12\x1c\n\tthreshold\x18\x05 \x01(\tR\tthreshold\x12\x1e\n\nsignatures\x18\x06 \x01(\tR\nsignatures"H\n!GetERC20WithdrawalApprovalRequest\x12#\n\rwithdrawal_id\x18\x01 \x01(\tR\x0cwithdrawalId"\xf0\x01\n"GetERC20WithdrawalApprovalResponse\x12!\n\x0c\x61sset_source\x18\x01 \x01(\tR\x0b\x61ssetSource\x12\x16\n\x06\x61mount\x18\x02 \x01(\tR\x06\x61mount\x12\x16\n\x06\x65xpiry\x18\x03 \x01(\x03R\x06\x65xpiry\x12\x14\n\x05nonce\x18\x04 \x01(\tR\x05nonce\x12\x1e\n\nsignatures\x18\x05 \x01(\tR\nsignatures\x12%\n\x0etarget_address\x18\x06 \x01(\tR\rtargetAddress\x12\x1a\n\x08\x63reation\x18\x07 \x01(\x03R\x08\x63reation"2\n\x13GetLastTradeRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId"9\n\x14GetLastTradeResponse\x12!\n\x05trade\x18\x01 \x01(\x0b\x32\x0b.vega.TradeR\x05trade"\xbd\x02\n\x11ListTradesRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08order_id\x18\x02 \x01(\tH\x01R\x07orderId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x03 \x01(\tH\x02R\x07partyId\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x03R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x05 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x04R\tdateRange\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_order_idB\x0b\n\t_party_idB\r\n\x0b_paginationB\r\n\x0b_date_range"N\n\x12ListTradesResponse\x12\x38\n\x06trades\x18\x01 \x01(\x0b\x32 .datanode.api.v2.TradeConnectionR\x06trades"{\n\x0fTradeConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.TradeEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"D\n\tTradeEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.TradeR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"s\n\x14ObserveTradesRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_party_id"<\n\x15ObserveTradesResponse\x12#\n\x06trades\x18\x01 \x03(\x0b\x32\x0b.vega.TradeR\x06trades"<\n\x14GetOracleSpecRequest\x12$\n\x0eoracle_spec_id\x18\x01 \x01(\tR\x0coracleSpecId"J\n\x15GetOracleSpecResponse\x12\x31\n\x0boracle_spec\x18\x01 \x01(\x0b\x32\x10.vega.OracleSpecR\noracleSpec"i\n\x16ListOracleSpecsRequest\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"d\n\x17ListOracleSpecsResponse\x12I\n\x0coracle_specs\x18\x01 \x01(\x0b\x32&.datanode.api.v2.OracleSpecsConnectionR\x0boracleSpecs"\xa6\x01\n\x15ListOracleDataRequest\x12)\n\x0eoracle_spec_id\x18\x01 \x01(\tH\x00R\x0coracleSpecId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x11\n\x0f_oracle_spec_idB\r\n\x0b_pagination"`\n\x16ListOracleDataResponse\x12\x46\n\x0boracle_data\x18\x01 \x01(\x0b\x32%.datanode.api.v2.OracleDataConnectionR\noracleData"N\n\x0eOracleSpecEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.OracleSpecR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15OracleSpecsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.OracleSpecEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"N\n\x0eOracleDataEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.OracleDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x85\x01\n\x14OracleDataConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.OracleDataEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"/\n\x10GetMarketRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId"9\n\x11GetMarketResponse\x12$\n\x06market\x18\x01 \x01(\x0b\x32\x0c.vega.MarketR\x06market"e\n\x12ListMarketsRequest\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"R\n\x13ListMarketsResponse\x12;\n\x07markets\x18\x01 \x01(\x0b\x32!.datanode.api.v2.MarketConnectionR\x07markets"F\n\nMarketEdge\x12 \n\x04node\x18\x01 \x01(\x0b\x32\x0c.vega.MarketR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"}\n\x10MarketConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.MarketEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo",\n\x0fGetPartyRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId"5\n\x10GetPartyResponse\x12!\n\x05party\x18\x01 \x01(\x0b\x32\x0b.vega.PartyR\x05party"l\n\x12ListPartiesRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12;\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"Q\n\x13ListPartiesResponse\x12:\n\x07parties\x18\x01 \x01(\x0b\x32 .datanode.api.v2.PartyConnectionR\x07parties"D\n\tPartyEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.PartyR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"{\n\x0fPartyConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.PartyEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"D\n\tOrderEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.OrderR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8e\x01\n\x17ListMarginLevelsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12;\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationR\npagination"b\n\x18ListMarginLevelsResponse\x12\x46\n\rmargin_levels\x18\x01 \x01(\x0b\x32!.datanode.api.v2.MarginConnectionR\x0cmarginLevels"g\n\x1aObserveMarginLevelsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12 \n\tmarket_id\x18\x02 \x01(\tH\x00R\x08marketId\x88\x01\x01\x42\x0c\n\n_market_id"V\n\x1bObserveMarginLevelsResponse\x12\x37\n\rmargin_levels\x18\x01 \x01(\x0b\x32\x12.vega.MarginLevelsR\x0cmarginLevels"{\n\x0fOrderConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.OrderEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"L\n\nMarginEdge\x12&\n\x04node\x18\x01 \x01(\x0b\x32\x12.vega.MarginLevelsR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"}\n\x10MarginConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.MarginEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xad\x01\n\x12ListRewardsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\x1e\n\x08\x61sset_id\x18\x02 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x0b\n\t_asset_idB\r\n\x0b_pagination"S\n\x13ListRewardsResponse\x12<\n\x07rewards\x18\x01 \x01(\x0b\x32".datanode.api.v2.RewardsConnectionR\x07rewards"F\n\nRewardEdge\x12 \n\x04node\x18\x01 \x01(\x0b\x32\x0c.vega.RewardR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"~\n\x11RewardsConnection\x12\x31\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1b.datanode.api.v2.RewardEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xc7\x01\n\x1aListRewardSummariesRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1e\n\x08\x61sset_id\x18\x02 \x01(\tH\x01R\x07\x61ssetId\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\x0b\n\t_party_idB\x0b\n\t_asset_idB\r\n\x0b_pagination"P\n\x1bListRewardSummariesResponse\x12\x31\n\tsummaries\x18\x01 \x03(\x0b\x32\x13.vega.RewardSummaryR\tsummaries"q\n\x15ObserveRewardsRequest\x12\x1e\n\x08\x61sset_id\x18\x01 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x42\x0b\n\t_asset_idB\x0b\n\t_party_id">\n\x16ObserveRewardsResponse\x12$\n\x06reward\x18\x01 \x01(\x0b\x32\x0c.vega.RewardR\x06reward"#\n\x11GetDepositRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"=\n\x12GetDepositResponse\x12\'\n\x07\x64\x65posit\x18\x01 \x01(\x0b\x32\r.vega.DepositR\x07\x64\x65posit"\xd0\x01\n\x13ListDepositsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x03 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"W\n\x14ListDepositsResponse\x12?\n\x08\x64\x65posits\x18\x01 \x01(\x0b\x32#.datanode.api.v2.DepositsConnectionR\x08\x64\x65posits"H\n\x0b\x44\x65positEdge\x12!\n\x04node\x18\x01 \x01(\x0b\x32\r.vega.DepositR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x80\x01\n\x12\x44\x65positsConnection\x12\x32\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1c.datanode.api.v2.DepositEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"&\n\x14GetWithdrawalRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"I\n\x15GetWithdrawalResponse\x12\x30\n\nwithdrawal\x18\x01 \x01(\x0b\x32\x10.vega.WithdrawalR\nwithdrawal"\xd3\x01\n\x16ListWithdrawalsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x12>\n\ndate_range\x18\x03 \x01(\x0b\x32\x1a.datanode.api.v2.DateRangeH\x01R\tdateRange\x88\x01\x01\x42\r\n\x0b_paginationB\r\n\x0b_date_range"c\n\x17ListWithdrawalsResponse\x12H\n\x0bwithdrawals\x18\x01 \x01(\x0b\x32&.datanode.api.v2.WithdrawalsConnectionR\x0bwithdrawals"N\n\x0eWithdrawalEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.WithdrawalR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15WithdrawalsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.WithdrawalEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo",\n\x0fGetAssetRequest\x12\x19\n\x08\x61sset_id\x18\x01 \x01(\tR\x07\x61ssetId"5\n\x10GetAssetResponse\x12!\n\x05\x61sset\x18\x01 \x01(\x0b\x32\x0b.vega.AssetR\x05\x61sset"\x91\x01\n\x11ListAssetsRequest\x12\x1e\n\x08\x61sset_id\x18\x01 \x01(\tH\x00R\x07\x61ssetId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x0b\n\t_asset_idB\r\n\x0b_pagination"O\n\x12ListAssetsResponse\x12\x39\n\x06\x61ssets\x18\x01 \x01(\x0b\x32!.datanode.api.v2.AssetsConnectionR\x06\x61ssets"D\n\tAssetEdge\x12\x1f\n\x04node\x18\x01 \x01(\x0b\x32\x0b.vega.AssetR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"|\n\x10\x41ssetsConnection\x12\x30\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1a.datanode.api.v2.AssetEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\xff\x01\n\x1eListLiquidityProvisionsRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x12!\n\treference\x18\x03 \x01(\tH\x02R\treference\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x03R\npagination\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_party_idB\x0c\n\n_referenceB\r\n\x0b_pagination"\x84\x01\n\x1fListLiquidityProvisionsResponse\x12\x61\n\x14liquidity_provisions\x18\x01 \x01(\x0b\x32..datanode.api.v2.LiquidityProvisionsConnectionR\x13liquidityProvisions"_\n\x17LiquidityProvisionsEdge\x12,\n\x04node\x18\x01 \x01(\x0b\x32\x18.vega.LiquidityProvisionR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x97\x01\n\x1dLiquidityProvisionsConnection\x12>\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32(.datanode.api.v2.LiquidityProvisionsEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x80\x01\n!ObserveLiquidityProvisionsRequest\x12 \n\tmarket_id\x18\x01 \x01(\tH\x00R\x08marketId\x88\x01\x01\x12\x1e\n\x08party_id\x18\x02 \x01(\tH\x01R\x07partyId\x88\x01\x01\x42\x0c\n\n_market_idB\x0b\n\t_party_id"q\n"ObserveLiquidityProvisionsResponse\x12K\n\x14liquidity_provisions\x18\x01 \x03(\x0b\x32\x18.vega.LiquidityProvisionR\x13liquidityProvisions"\x81\x01\n\x18GetGovernanceDataRequest\x12$\n\x0bproposal_id\x18\x01 \x01(\tH\x00R\nproposalId\x88\x01\x01\x12!\n\treference\x18\x02 \x01(\tH\x01R\treference\x88\x01\x01\x42\x0e\n\x0c_proposal_idB\x0c\n\n_reference"E\n\x19GetGovernanceDataResponse\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceDataR\x04\x64\x61ta"\xfa\x04\n\x19ListGovernanceDataRequest\x12@\n\x0eproposal_state\x18\x01 \x01(\x0e\x32\x14.vega.Proposal.StateH\x00R\rproposalState\x88\x01\x01\x12Y\n\rproposal_type\x18\x02 \x01(\x0e\x32/.datanode.api.v2.ListGovernanceDataRequest.TypeH\x01R\x0cproposalType\x88\x01\x01\x12/\n\x11proposer_party_id\x18\x03 \x01(\tH\x02R\x0fproposerPartyId\x88\x01\x01\x12\x32\n\x12proposal_reference\x18\x04 \x01(\tH\x03R\x11proposalReference\x88\x01\x01\x12@\n\npagination\x18\x05 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x04R\npagination\x88\x01\x01"\xb7\x01\n\x04Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x0c\n\x08TYPE_ALL\x10\x01\x12\x13\n\x0fTYPE_NEW_MARKET\x10\x02\x12\x16\n\x12TYPE_UPDATE_MARKET\x10\x03\x12\x1b\n\x17TYPE_NETWORK_PARAMETERS\x10\x04\x12\x12\n\x0eTYPE_NEW_ASSET\x10\x05\x12\x16\n\x12TYPE_NEW_FREE_FORM\x10\x06\x12\x15\n\x11TYPE_UPDATE_ASSET\x10\x07\x42\x11\n\x0f_proposal_stateB\x10\n\x0e_proposal_typeB\x14\n\x12_proposer_party_idB\x15\n\x13_proposal_referenceB\r\n\x0b_pagination"g\n\x1aListGovernanceDataResponse\x12I\n\nconnection\x18\x01 \x01(\x0b\x32).datanode.api.v2.GovernanceDataConnectionR\nconnection"V\n\x12GovernanceDataEdge\x12(\n\x04node\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceDataR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8d\x01\n\x18GovernanceDataConnection\x12\x39\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32#.datanode.api.v2.GovernanceDataEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"G\n\x18ObserveGovernanceRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x42\x0b\n\t_party_id"E\n\x19ObserveGovernanceResponse\x12(\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x14.vega.GovernanceDataR\x04\x64\x61ta"\xed\x01\n\x16ListDelegationsRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1c\n\x07node_id\x18\x02 \x01(\tH\x01R\x06nodeId\x88\x01\x01\x12\x1e\n\x08\x65poch_id\x18\x03 \x01(\tH\x02R\x07\x65pochId\x88\x01\x01\x12@\n\npagination\x18\x04 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x03R\npagination\x88\x01\x01\x42\x0b\n\t_party_idB\n\n\x08_node_idB\x0b\n\t_epoch_idB\r\n\x0b_pagination"c\n\x17ListDelegationsResponse\x12H\n\x0b\x64\x65legations\x18\x01 \x01(\x0b\x32&.datanode.api.v2.DelegationsConnectionR\x0b\x64\x65legations"N\n\x0e\x44\x65legationEdge\x12$\n\x04node\x18\x01 \x01(\x0b\x32\x10.vega.DelegationR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15\x44\x65legationsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.DelegationEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"r\n\x19ObserveDelegationsRequest\x12\x1e\n\x08party_id\x18\x01 \x01(\tH\x00R\x07partyId\x88\x01\x01\x12\x1c\n\x07node_id\x18\x02 \x01(\tH\x01R\x06nodeId\x88\x01\x01\x42\x0b\n\t_party_idB\n\n\x08_node_id"N\n\x1aObserveDelegationsResponse\x12\x30\n\ndelegation\x18\x01 \x01(\x0b\x32\x10.vega.DelegationR\ndelegation"\x17\n\x15GetNetworkDataRequest"E\n\x16GetNetworkDataResponse\x12+\n\tnode_data\x18\x01 \x01(\x0b\x32\x0e.vega.NodeDataR\x08nodeData" \n\x0eGetNodeRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id"1\n\x0fGetNodeResponse\x12\x1e\n\x04node\x18\x01 \x01(\x0b\x32\n.vega.NodeR\x04node"\x93\x01\n\x10ListNodesRequest\x12 \n\tepoch_seq\x18\x01 \x01(\x04H\x00R\x08\x65pochSeq\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\x0c\n\n_epoch_seqB\r\n\x0b_pagination"K\n\x11ListNodesResponse\x12\x36\n\x05nodes\x18\x01 \x01(\x0b\x32 .datanode.api.v2.NodesConnectionR\x05nodes"B\n\x08NodeEdge\x12\x1e\n\x04node\x18\x01 \x01(\x0b\x32\n.vega.NodeR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"z\n\x0fNodesConnection\x12/\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x19.datanode.api.v2.NodeEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"|\n\x19ListNodeSignaturesRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"g\n\x1aListNodeSignaturesResponse\x12I\n\nsignatures\x18\x01 \x01(\x0b\x32).datanode.api.v2.NodeSignaturesConnectionR\nsignatures"`\n\x11NodeSignatureEdge\x12\x33\n\x04node\x18\x01 \x01(\x0b\x32\x1f.vega.commands.v1.NodeSignatureR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x8c\x01\n\x18NodeSignaturesConnection\x12\x38\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32".datanode.api.v2.NodeSignatureEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"-\n\x0fGetEpochRequest\x12\x13\n\x02id\x18\x01 \x01(\x04H\x00R\x02id\x88\x01\x01\x42\x05\n\x03_id"5\n\x10GetEpochResponse\x12!\n\x05\x65poch\x18\x01 \x01(\x0b\x32\x0b.vega.EpochR\x05\x65poch"[\n\x12\x45stimateFeeRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x14\n\x05price\x18\x02 \x01(\tR\x05price\x12\x12\n\x04size\x18\x03 \x01(\x04R\x04size"2\n\x13\x45stimateFeeResponse\x12\x1b\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\t.vega.FeeR\x03\x66\x65\x65"\xbf\x01\n\x15\x45stimateMarginRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x02 \x01(\tR\x07partyId\x12\x1e\n\x04side\x18\x03 \x01(\x0e\x32\n.vega.SideR\x04side\x12$\n\x04type\x18\x04 \x01(\x0e\x32\x10.vega.Order.TypeR\x04type\x12\x12\n\x04size\x18\x05 \x01(\x04R\x04size\x12\x14\n\x05price\x18\x06 \x01(\tR\x05price"Q\n\x16\x45stimateMarginResponse\x12\x37\n\rmargin_levels\x18\x02 \x01(\x0b\x32\x12.vega.MarginLevelsR\x0cmarginLevels"o\n\x1cListNetworkParametersRequest\x12@\n\npagination\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"{\n\x1dListNetworkParametersResponse\x12Z\n\x12network_parameters\x18\x01 \x01(\x0b\x32+.datanode.api.v2.NetworkParameterConnectionR\x11networkParameters".\n\x1aGetNetworkParameterRequest\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key"b\n\x1bGetNetworkParameterResponse\x12\x43\n\x11network_parameter\x18\x01 \x01(\x0b\x32\x16.vega.NetworkParameterR\x10networkParameter"Z\n\x14NetworkParameterEdge\x12*\n\x04node\x18\x01 \x01(\x0b\x32\x16.vega.NetworkParameterR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x91\x01\n\x1aNetworkParameterConnection\x12;\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32%.datanode.api.v2.NetworkParameterEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"Z\n\nCheckpoint\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x1d\n\nblock_hash\x18\x02 \x01(\tR\tblockHash\x12\x19\n\x08\x61t_block\x18\x03 \x01(\x04R\x07\x61tBlock"i\n\x16ListCheckpointsRequest\x12@\n\npagination\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"c\n\x17ListCheckpointsResponse\x12H\n\x0b\x63heckpoints\x18\x01 \x01(\x0b\x32&.datanode.api.v2.CheckpointsConnectionR\x0b\x63heckpoints"Y\n\x0e\x43heckpointEdge\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x1b.datanode.api.v2.CheckpointR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x86\x01\n\x15\x43heckpointsConnection\x12\x35\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.CheckpointEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"}\n\x0fGetStakeRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x00R\npagination\x88\x01\x01\x42\r\n\x0b_pagination"\x94\x01\n\x10GetStakeResponse\x12\x36\n\x17\x63urrent_stake_available\x18\x01 \x01(\tR\x15\x63urrentStakeAvailable\x12H\n\x0estake_linkings\x18\x02 \x01(\x0b\x32!.datanode.api.v2.StakesConnectionR\rstakeLinkings"\\\n\x10StakeLinkingEdge\x12\x30\n\x04node\x18\x01 \x01(\x0b\x32\x1c.vega.events.v1.StakeLinkingR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x83\x01\n\x10StakesConnection\x12\x37\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32!.datanode.api.v2.StakeLinkingEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"4\n\x15GetRiskFactorsRequest\x12\x1b\n\tmarket_id\x18\x01 \x01(\tR\x08marketId"K\n\x16GetRiskFactorsResponse\x12\x31\n\x0brisk_factor\x18\x01 \x01(\x0b\x32\x10.vega.RiskFactorR\nriskFactor"\xa1\x01\n\x16ObserveEventBusRequest\x12\x30\n\x04type\x18\x01 \x03(\x0e\x32\x1c.vega.events.v1.BusEventTypeR\x04type\x12\x1b\n\tmarket_id\x18\x02 \x01(\tR\x08marketId\x12\x19\n\x08party_id\x18\x03 \x01(\tR\x07partyId\x12\x1d\n\nbatch_size\x18\x04 \x01(\x03R\tbatchSize"K\n\x17ObserveEventBusResponse\x12\x30\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x18.vega.events.v1.BusEventR\x06\x65vents"\x1f\n\x1dObserveLedgerMovementsRequest"_\n\x1eObserveLedgerMovementsResponse\x12=\n\x0fledger_movement\x18\x01 \x01(\x0b\x32\x14.vega.LedgerMovementR\x0eledgerMovement"\x94\x01\n\x17ListKeyRotationsRequest\x12\x1c\n\x07node_id\x18\x01 \x01(\tH\x00R\x06nodeId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\n\n\x08_node_idB\r\n\x0b_pagination"`\n\x18ListKeyRotationsResponse\x12\x44\n\trotations\x18\x01 \x01(\x0b\x32&.datanode.api.v2.KeyRotationConnectionR\trotations"Z\n\x0fKeyRotationEdge\x12/\n\x04node\x18\x01 \x01(\x0b\x32\x1b.vega.events.v1.KeyRotationR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x87\x01\n\x15KeyRotationConnection\x12\x36\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32 .datanode.api.v2.KeyRotationEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x9c\x01\n\x1fListEthereumKeyRotationsRequest\x12\x1c\n\x07node_id\x18\x01 \x01(\tH\x00R\x06nodeId\x88\x01\x01\x12@\n\npagination\x18\x02 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x01R\npagination\x88\x01\x01\x42\n\n\x08_node_idB\r\n\x0b_pagination"x\n ListEthereumKeyRotationsResponse\x12T\n\rkey_rotations\x18\x01 \x01(\x0b\x32/.datanode.api.v2.EthereumKeyRotationsConnectionR\x0ckeyRotations"\x98\x01\n\x1e\x45thereumKeyRotationsConnection\x12>\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32(.datanode.api.v2.EthereumKeyRotationEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"\x8a\x01\n\x17\x45thereumKeyRotationEdge\x12W\n\x15\x65thereum_key_rotation\x18\x01 \x01(\x0b\x32#.vega.events.v1.EthereumKeyRotationR\x13\x65thereumKeyRotation\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\x14\n\x12GetVegaTimeRequest"3\n\x13GetVegaTimeResponse\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp"\x89\x01\n\tDateRange\x12,\n\x0fstart_timestamp\x18\x01 \x01(\x03H\x00R\x0estartTimestamp\x88\x01\x01\x12(\n\rend_timestamp\x18\x02 \x01(\x03H\x01R\x0c\x65ndTimestamp\x88\x01\x01\x42\x12\n\x10_start_timestampB\x10\n\x0e_end_timestamp"!\n\x1fGetProtocolUpgradeStatusRequest"8\n GetProtocolUpgradeStatusResponse\x12\x14\n\x05ready\x18\x01 \x01(\x08R\x05ready"\x83\x02\n#ListProtocolUpgradeProposalsRequest\x12J\n\x06status\x18\x01 \x01(\x0e\x32-.vega.events.v1.ProtocolUpgradeProposalStatusH\x00R\x06status\x88\x01\x01\x12$\n\x0b\x61pproved_by\x18\x02 \x01(\tH\x01R\napprovedBy\x88\x01\x01\x12@\n\npagination\x18\x03 \x01(\x0b\x32\x1b.datanode.api.v2.PaginationH\x02R\npagination\x88\x01\x01\x42\t\n\x07_statusB\x0e\n\x0c_approved_byB\r\n\x0b_pagination"\x98\x01\n$ListProtocolUpgradeProposalsResponse\x12p\n\x1aprotocol_upgrade_proposals\x18\x01 \x01(\x0b\x32\x32.datanode.api.v2.ProtocolUpgradeProposalConnectionR\x18protocolUpgradeProposals"\x9f\x01\n!ProtocolUpgradeProposalConnection\x12\x42\n\x05\x65\x64ges\x18\x01 \x03(\x0b\x32,.datanode.api.v2.ProtocolUpgradeProposalEdgeR\x05\x65\x64ges\x12\x36\n\tpage_info\x18\x02 \x01(\x0b\x32\x19.datanode.api.v2.PageInfoR\x08pageInfo"o\n\x1bProtocolUpgradeProposalEdge\x12\x38\n\x04node\x18\x01 \x01(\x0b\x32$.vega.events.v1.ProtocolUpgradeEventR\x04node\x12\x16\n\x06\x63ursor\x18\x02 \x01(\tR\x06\x63ursor"\xd6\x01\n\x0eHistorySegment\x12\x1f\n\x0b\x66rom_height\x18\x01 \x01(\x03R\nfromHeight\x12\x1b\n\tto_height\x18\x02 \x01(\x03R\x08toHeight\x12\x19\n\x08\x63hain_id\x18\x03 \x01(\tR\x07\x63hainId\x12,\n\x12history_segment_id\x18\x04 \x01(\tR\x10historySegmentId\x12=\n\x1bprevious_history_segment_id\x18\x05 \x01(\tR\x18previousHistorySegmentId"&\n$GetMostRecentDeHistorySegmentRequest"b\n%GetMostRecentDeHistorySegmentResponse\x12\x39\n\x07segment\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.HistorySegmentR\x07segment"!\n\x1fListAllDeHistorySegmentsRequest"_\n ListAllDeHistorySegmentsResponse\x12;\n\x08segments\x18\x01 \x03(\x0b\x32\x1f.datanode.api.v2.HistorySegmentR\x08segments"L\n\x1c\x46\x65tchDeHistorySegmentRequest\x12,\n\x12history_segment_id\x18\x01 \x01(\tR\x10historySegmentId"Z\n\x1d\x46\x65tchDeHistorySegmentResponse\x12\x39\n\x07segment\x18\x01 \x01(\x0b\x32\x1f.datanode.api.v2.HistorySegmentR\x07segment"(\n&GetActiveDeHistoryPeerAddressesRequest"L\n\'GetActiveDeHistoryPeerAddressesResponse\x12!\n\x0cip_addresses\x18\x01 \x03(\tR\x0bipAddresses"p\n\x1f\x43opyHistorySegmentToFileRequest\x12,\n\x12history_segment_id\x18\x01 \x01(\tR\x10historySegmentId\x12\x1f\n\x0btarget_file\x18\x02 \x01(\tR\ntargetFile""\n CopyHistorySegmentToFileResponse"\r\n\x0bPingRequest"\x0e\n\x0cPingResponse*\xaa\x01\n\x10LedgerEntryField\x12"\n\x1eLEDGER_ENTRY_FIELD_UNSPECIFIED\x10\x00\x12&\n"LEDGER_ENTRY_FIELD_ACCOUNT_FROM_ID\x10\x01\x12$\n LEDGER_ENTRY_FIELD_ACCOUNT_TO_ID\x10\x02\x12$\n LEDGER_ENTRY_FIELD_TRANSFER_TYPE\x10\x03*\xb0\x01\n\x0c\x41\x63\x63ountField\x12\x1d\n\x19\x41\x43\x43OUNT_FIELD_UNSPECIFIED\x10\x00\x12\x14\n\x10\x41\x43\x43OUNT_FIELD_ID\x10\x01\x12\x1a\n\x16\x41\x43\x43OUNT_FIELD_PARTY_ID\x10\x02\x12\x1a\n\x16\x41\x43\x43OUNT_FIELD_ASSET_ID\x10\x03\x12\x1b\n\x17\x41\x43\x43OUNT_FIELD_MARKET_ID\x10\x04\x12\x16\n\x12\x41\x43\x43OUNT_FIELD_TYPE\x10\x05*\xad\x01\n\x11TransferDirection\x12"\n\x1eTRANSFER_DIRECTION_UNSPECIFIED\x10\x00\x12$\n TRANSFER_DIRECTION_TRANSFER_FROM\x10\x01\x12"\n\x1eTRANSFER_DIRECTION_TRANSFER_TO\x10\x02\x12*\n&TRANSFER_DIRECTION_TRANSFER_TO_OR_FROM\x10\x03\x32\xc0\x45\n\x12TradingDataService\x12[\n\x0cListAccounts\x12$.datanode.api.v2.ListAccountsRequest\x1a%.datanode.api.v2.ListAccountsResponse\x12\x66\n\x0fObserveAccounts\x12\'.datanode.api.v2.ObserveAccountsRequest\x1a(.datanode.api.v2.ObserveAccountsResponse0\x01\x12\x43\n\x04Info\x12\x1c.datanode.api.v2.InfoRequest\x1a\x1d.datanode.api.v2.InfoResponse\x12O\n\x08GetOrder\x12 .datanode.api.v2.GetOrderRequest\x1a!.datanode.api.v2.GetOrderResponse\x12U\n\nListOrders\x12".datanode.api.v2.ListOrdersRequest\x1a#.datanode.api.v2.ListOrdersResponse\x12j\n\x11ListOrderVersions\x12).datanode.api.v2.ListOrderVersionsRequest\x1a*.datanode.api.v2.ListOrderVersionsResponse\x12`\n\rObserveOrders\x12%.datanode.api.v2.ObserveOrdersRequest\x1a&.datanode.api.v2.ObserveOrdersResponse0\x01\x12^\n\rListPositions\x12%.datanode.api.v2.ListPositionsRequest\x1a&.datanode.api.v2.ListPositionsResponse\x12i\n\x10ObservePositions\x12(.datanode.api.v2.ObservePositionsRequest\x1a).datanode.api.v2.ObservePositionsResponse0\x01\x12l\n\x11ListLedgerEntries\x12).datanode.api.v2.ListLedgerEntriesRequest\x1a*.datanode.api.v2.ListLedgerEntriesResponse"\x00\x12o\n\x12ListBalanceChanges\x12*.datanode.api.v2.ListBalanceChangesRequest\x1a+.datanode.api.v2.ListBalanceChangesResponse"\x00\x12p\n\x13GetLatestMarketData\x12+.datanode.api.v2.GetLatestMarketDataRequest\x1a,.datanode.api.v2.GetLatestMarketDataResponse\x12s\n\x14ListLatestMarketData\x12,.datanode.api.v2.ListLatestMarketDataRequest\x1a-.datanode.api.v2.ListLatestMarketDataResponse\x12s\n\x14GetLatestMarketDepth\x12,.datanode.api.v2.GetLatestMarketDepthRequest\x1a-.datanode.api.v2.GetLatestMarketDepthResponse\x12r\n\x13ObserveMarketsDepth\x12+.datanode.api.v2.ObserveMarketsDepthRequest\x1a,.datanode.api.v2.ObserveMarketsDepthResponse0\x01\x12\x87\x01\n\x1aObserveMarketsDepthUpdates\x12\x32.datanode.api.v2.ObserveMarketsDepthUpdatesRequest\x1a\x33.datanode.api.v2.ObserveMarketsDepthUpdatesResponse0\x01\x12o\n\x12ObserveMarketsData\x12*.datanode.api.v2.ObserveMarketsDataRequest\x1a+.datanode.api.v2.ObserveMarketsDataResponse0\x01\x12\x7f\n\x18GetMarketDataHistoryByID\x12\x30.datanode.api.v2.GetMarketDataHistoryByIDRequest\x1a\x31.datanode.api.v2.GetMarketDataHistoryByIDResponse\x12^\n\rListTransfers\x12%.datanode.api.v2.ListTransfersRequest\x1a&.datanode.api.v2.ListTransfersResponse\x12g\n\x10GetNetworkLimits\x12(.datanode.api.v2.GetNetworkLimitsRequest\x1a).datanode.api.v2.GetNetworkLimitsResponse\x12\x61\n\x0eListCandleData\x12&.datanode.api.v2.ListCandleDataRequest\x1a\'.datanode.api.v2.ListCandleDataResponse\x12l\n\x11ObserveCandleData\x12).datanode.api.v2.ObserveCandleDataRequest\x1a*.datanode.api.v2.ObserveCandleDataResponse0\x01\x12p\n\x13ListCandleIntervals\x12+.datanode.api.v2.ListCandleIntervalsRequest\x1a,.datanode.api.v2.ListCandleIntervalsResponse\x12R\n\tListVotes\x12!.datanode.api.v2.ListVotesRequest\x1a".datanode.api.v2.ListVotesResponse\x12]\n\x0cObserveVotes\x12$.datanode.api.v2.ObserveVotesRequest\x1a%.datanode.api.v2.ObserveVotesResponse0\x01\x12\xa0\x01\n#ListERC20MultiSigSignerAddedBundles\x12;.datanode.api.v2.ListERC20MultiSigSignerAddedBundlesRequest\x1a<.datanode.api.v2.ListERC20MultiSigSignerAddedBundlesResponse\x12\xa6\x01\n%ListERC20MultiSigSignerRemovedBundles\x12=.datanode.api.v2.ListERC20MultiSigSignerRemovedBundlesRequest\x1a>.datanode.api.v2.ListERC20MultiSigSignerRemovedBundlesResponse\x12|\n\x17GetERC20ListAssetBundle\x12/.datanode.api.v2.GetERC20ListAssetBundleRequest\x1a\x30.datanode.api.v2.GetERC20ListAssetBundleResponse\x12\x8b\x01\n\x1cGetERC20SetAssetLimitsBundle\x12\x34.datanode.api.v2.GetERC20SetAssetLimitsBundleRequest\x1a\x35.datanode.api.v2.GetERC20SetAssetLimitsBundleResponse\x12\x85\x01\n\x1aGetERC20WithdrawalApproval\x12\x32.datanode.api.v2.GetERC20WithdrawalApprovalRequest\x1a\x33.datanode.api.v2.GetERC20WithdrawalApprovalResponse\x12[\n\x0cGetLastTrade\x12$.datanode.api.v2.GetLastTradeRequest\x1a%.datanode.api.v2.GetLastTradeResponse\x12U\n\nListTrades\x12".datanode.api.v2.ListTradesRequest\x1a#.datanode.api.v2.ListTradesResponse\x12`\n\rObserveTrades\x12%.datanode.api.v2.ObserveTradesRequest\x1a&.datanode.api.v2.ObserveTradesResponse0\x01\x12^\n\rGetOracleSpec\x12%.datanode.api.v2.GetOracleSpecRequest\x1a&.datanode.api.v2.GetOracleSpecResponse\x12\x64\n\x0fListOracleSpecs\x12\'.datanode.api.v2.ListOracleSpecsRequest\x1a(.datanode.api.v2.ListOracleSpecsResponse\x12\x61\n\x0eListOracleData\x12&.datanode.api.v2.ListOracleDataRequest\x1a\'.datanode.api.v2.ListOracleDataResponse\x12R\n\tGetMarket\x12!.datanode.api.v2.GetMarketRequest\x1a".datanode.api.v2.GetMarketResponse\x12X\n\x0bListMarkets\x12#.datanode.api.v2.ListMarketsRequest\x1a$.datanode.api.v2.ListMarketsResponse\x12O\n\x08GetParty\x12 .datanode.api.v2.GetPartyRequest\x1a!.datanode.api.v2.GetPartyResponse\x12X\n\x0bListParties\x12#.datanode.api.v2.ListPartiesRequest\x1a$.datanode.api.v2.ListPartiesResponse\x12g\n\x10ListMarginLevels\x12(.datanode.api.v2.ListMarginLevelsRequest\x1a).datanode.api.v2.ListMarginLevelsResponse\x12r\n\x13ObserveMarginLevels\x12+.datanode.api.v2.ObserveMarginLevelsRequest\x1a,.datanode.api.v2.ObserveMarginLevelsResponse0\x01\x12X\n\x0bListRewards\x12#.datanode.api.v2.ListRewardsRequest\x1a$.datanode.api.v2.ListRewardsResponse\x12p\n\x13ListRewardSummaries\x12+.datanode.api.v2.ListRewardSummariesRequest\x1a,.datanode.api.v2.ListRewardSummariesResponse\x12\x63\n\x0eObserveRewards\x12&.datanode.api.v2.ObserveRewardsRequest\x1a\'.datanode.api.v2.ObserveRewardsResponse0\x01\x12U\n\nGetDeposit\x12".datanode.api.v2.GetDepositRequest\x1a#.datanode.api.v2.GetDepositResponse\x12[\n\x0cListDeposits\x12$.datanode.api.v2.ListDepositsRequest\x1a%.datanode.api.v2.ListDepositsResponse\x12^\n\rGetWithdrawal\x12%.datanode.api.v2.GetWithdrawalRequest\x1a&.datanode.api.v2.GetWithdrawalResponse\x12\x64\n\x0fListWithdrawals\x12\'.datanode.api.v2.ListWithdrawalsRequest\x1a(.datanode.api.v2.ListWithdrawalsResponse\x12O\n\x08GetAsset\x12 .datanode.api.v2.GetAssetRequest\x1a!.datanode.api.v2.GetAssetResponse\x12U\n\nListAssets\x12".datanode.api.v2.ListAssetsRequest\x1a#.datanode.api.v2.ListAssetsResponse\x12|\n\x17ListLiquidityProvisions\x12/.datanode.api.v2.ListLiquidityProvisionsRequest\x1a\x30.datanode.api.v2.ListLiquidityProvisionsResponse\x12\x87\x01\n\x1aObserveLiquidityProvisions\x12\x32.datanode.api.v2.ObserveLiquidityProvisionsRequest\x1a\x33.datanode.api.v2.ObserveLiquidityProvisionsResponse0\x01\x12j\n\x11GetGovernanceData\x12).datanode.api.v2.GetGovernanceDataRequest\x1a*.datanode.api.v2.GetGovernanceDataResponse\x12m\n\x12ListGovernanceData\x12*.datanode.api.v2.ListGovernanceDataRequest\x1a+.datanode.api.v2.ListGovernanceDataResponse\x12l\n\x11ObserveGovernance\x12).datanode.api.v2.ObserveGovernanceRequest\x1a*.datanode.api.v2.ObserveGovernanceResponse0\x01\x12\x64\n\x0fListDelegations\x12\'.datanode.api.v2.ListDelegationsRequest\x1a(.datanode.api.v2.ListDelegationsResponse\x12o\n\x12ObserveDelegations\x12*.datanode.api.v2.ObserveDelegationsRequest\x1a+.datanode.api.v2.ObserveDelegationsResponse0\x01\x12\x61\n\x0eGetNetworkData\x12&.datanode.api.v2.GetNetworkDataRequest\x1a\'.datanode.api.v2.GetNetworkDataResponse\x12L\n\x07GetNode\x12\x1f.datanode.api.v2.GetNodeRequest\x1a .datanode.api.v2.GetNodeResponse\x12R\n\tListNodes\x12!.datanode.api.v2.ListNodesRequest\x1a".datanode.api.v2.ListNodesResponse\x12m\n\x12ListNodeSignatures\x12*.datanode.api.v2.ListNodeSignaturesRequest\x1a+.datanode.api.v2.ListNodeSignaturesResponse\x12O\n\x08GetEpoch\x12 .datanode.api.v2.GetEpochRequest\x1a!.datanode.api.v2.GetEpochResponse\x12X\n\x0b\x45stimateFee\x12#.datanode.api.v2.EstimateFeeRequest\x1a$.datanode.api.v2.EstimateFeeResponse\x12\x61\n\x0e\x45stimateMargin\x12&.datanode.api.v2.EstimateMarginRequest\x1a\'.datanode.api.v2.EstimateMarginResponse\x12v\n\x15ListNetworkParameters\x12-.datanode.api.v2.ListNetworkParametersRequest\x1a..datanode.api.v2.ListNetworkParametersResponse\x12p\n\x13GetNetworkParameter\x12+.datanode.api.v2.GetNetworkParameterRequest\x1a,.datanode.api.v2.GetNetworkParameterResponse\x12\x64\n\x0fListCheckpoints\x12\'.datanode.api.v2.ListCheckpointsRequest\x1a(.datanode.api.v2.ListCheckpointsResponse\x12O\n\x08GetStake\x12 .datanode.api.v2.GetStakeRequest\x1a!.datanode.api.v2.GetStakeResponse\x12\x61\n\x0eGetRiskFactors\x12&.datanode.api.v2.GetRiskFactorsRequest\x1a\'.datanode.api.v2.GetRiskFactorsResponse\x12h\n\x0fObserveEventBus\x12\'.datanode.api.v2.ObserveEventBusRequest\x1a(.datanode.api.v2.ObserveEventBusResponse(\x01\x30\x01\x12{\n\x16ObserveLedgerMovements\x12..datanode.api.v2.ObserveLedgerMovementsRequest\x1a/.datanode.api.v2.ObserveLedgerMovementsResponse0\x01\x12g\n\x10ListKeyRotations\x12(.datanode.api.v2.ListKeyRotationsRequest\x1a).datanode.api.v2.ListKeyRotationsResponse\x12\x7f\n\x18ListEthereumKeyRotations\x12\x30.datanode.api.v2.ListEthereumKeyRotationsRequest\x1a\x31.datanode.api.v2.ListEthereumKeyRotationsResponse\x12X\n\x0bGetVegaTime\x12#.datanode.api.v2.GetVegaTimeRequest\x1a$.datanode.api.v2.GetVegaTimeResponse\x12\x7f\n\x18GetProtocolUpgradeStatus\x12\x30.datanode.api.v2.GetProtocolUpgradeStatusRequest\x1a\x31.datanode.api.v2.GetProtocolUpgradeStatusResponse\x12\x8b\x01\n\x1cListProtocolUpgradeProposals\x12\x34.datanode.api.v2.ListProtocolUpgradeProposalsRequest\x1a\x35.datanode.api.v2.ListProtocolUpgradeProposalsResponse\x12\x8e\x01\n\x1dGetMostRecentDeHistorySegment\x12\x35.datanode.api.v2.GetMostRecentDeHistorySegmentRequest\x1a\x36.datanode.api.v2.GetMostRecentDeHistorySegmentResponse\x12\x7f\n\x18ListAllDeHistorySegments\x12\x30.datanode.api.v2.ListAllDeHistorySegmentsRequest\x1a\x31.datanode.api.v2.ListAllDeHistorySegmentsResponse\x12v\n\x15\x46\x65tchDeHistorySegment\x12-.datanode.api.v2.FetchDeHistorySegmentRequest\x1a..datanode.api.v2.FetchDeHistorySegmentResponse\x12\x94\x01\n\x1fGetActiveDeHistoryPeerAddresses\x12\x37.datanode.api.v2.GetActiveDeHistoryPeerAddressesRequest\x1a\x38.datanode.api.v2.GetActiveDeHistoryPeerAddressesResponse\x12\x7f\n\x18\x43opyHistorySegmentToFile\x12\x30.datanode.api.v2.CopyHistorySegmentToFileRequest\x1a\x31.datanode.api.v2.CopyHistorySegmentToFileResponse\x12\x43\n\x04Ping\x12\x1c.datanode.api.v2.PingRequest\x1a\x1d.datanode.api.v2.PingResponseB\x81\x01Z1code.vegaprotocol.io/vega/protos/data-node/api/v2\x92\x41K\x12"\n\x13Vega data node APIs2\x0bv0.63.0+dev\x1a!lb.testnet.vega.xyz/datanode/rest*\x02\x01\x02\x62\x06proto3'
)

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(
    DESCRIPTOR, "data_node.api.v2.trading_data_pb2", globals()
)
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b'Z1code.vegaprotocol.io/vega/protos/data-node/api/v2\222AK\022"\n\023Vega data node APIs2\013v0.63.0+dev\032!lb.testnet.vega.xyz/datanode/rest*\002\001\002'
    _GETMARKETDATAHISTORYBYIDREQUEST.fields_by_name["offset_pagination"]._options = None
    _GETMARKETDATAHISTORYBYIDREQUEST.fields_by_name[
        "offset_pagination"
    ]._serialized_options = b"\030\001"
    _LEDGERENTRYFIELD._serialized_start = 30351
    _LEDGERENTRYFIELD._serialized_end = 30521
    _ACCOUNTFIELD._serialized_start = 30524
    _ACCOUNTFIELD._serialized_end = 30700
    _TRANSFERDIRECTION._serialized_start = 30703
    _TRANSFERDIRECTION._serialized_end = 30876
    _OFFSETPAGINATION._serialized_start = 274
    _OFFSETPAGINATION._serialized_end = 366
    _PAGINATION._serialized_start = 369
    _PAGINATION._serialized_end = 586
    _PAGEINFO._serialized_start = 589
    _PAGEINFO._serialized_end = 745
    _ACCOUNTBALANCE._serialized_start = 748
    _ACCOUNTBALANCE._serialized_end = 902
    _LISTACCOUNTSREQUEST._serialized_start = 905
    _LISTACCOUNTSREQUEST._serialized_end = 1063
    _LISTACCOUNTSRESPONSE._serialized_start = 1065
    _LISTACCOUNTSRESPONSE._serialized_end = 1152
    _ACCOUNTSCONNECTION._serialized_start = 1155
    _ACCOUNTSCONNECTION._serialized_end = 1283
    _ACCOUNTEDGE._serialized_start = 1285
    _ACCOUNTEDGE._serialized_end = 1381
    _OBSERVEACCOUNTSREQUEST._serialized_start = 1384
    _OBSERVEACCOUNTSREQUEST._serialized_end = 1525
    _OBSERVEACCOUNTSRESPONSE._serialized_start = 1528
    _OBSERVEACCOUNTSRESPONSE._serialized_end = 1694
    _ACCOUNTSNAPSHOTPAGE._serialized_start = 1696
    _ACCOUNTSNAPSHOTPAGE._serialized_end = 1807
    _ACCOUNTUPDATES._serialized_start = 1809
    _ACCOUNTUPDATES._serialized_end = 1886
    _INFOREQUEST._serialized_start = 1888
    _INFOREQUEST._serialized_end = 1901
    _INFORESPONSE._serialized_start = 1903
    _INFORESPONSE._serialized_end = 1976
    _GETORDERREQUEST._serialized_start = 1978
    _GETORDERREQUEST._serialized_end = 2065
    _GETORDERRESPONSE._serialized_start = 2067
    _GETORDERRESPONSE._serialized_end = 2120
    _LISTORDERSREQUEST._serialized_start = 2123
    _LISTORDERSREQUEST._serialized_end = 2492
    _LISTORDERSRESPONSE._serialized_start = 2494
    _LISTORDERSRESPONSE._serialized_end = 2572
    _LISTORDERVERSIONSREQUEST._serialized_start = 2575
    _LISTORDERVERSIONSREQUEST._serialized_end = 2709
    _LISTORDERVERSIONSRESPONSE._serialized_start = 2711
    _LISTORDERVERSIONSRESPONSE._serialized_end = 2796
    _OBSERVEORDERSREQUEST._serialized_start = 2798
    _OBSERVEORDERSREQUEST._serialized_end = 2913
    _OBSERVEORDERSRESPONSE._serialized_start = 2916
    _OBSERVEORDERSRESPONSE._serialized_end = 3076
    _ORDERSNAPSHOTPAGE._serialized_start = 3078
    _ORDERSNAPSHOTPAGE._serialized_end = 3163
    _ORDERUPDATES._serialized_start = 3165
    _ORDERUPDATES._serialized_end = 3216
    _LISTPOSITIONSREQUEST._serialized_start = 3219
    _LISTPOSITIONSREQUEST._serialized_end = 3378
    _LISTPOSITIONSRESPONSE._serialized_start = 3380
    _LISTPOSITIONSRESPONSE._serialized_end = 3470
    _POSITIONEDGE._serialized_start = 3472
    _POSITIONEDGE._serialized_end = 3546
    _POSITIONCONNECTION._serialized_start = 3549
    _POSITIONCONNECTION._serialized_end = 3678
    _OBSERVEPOSITIONSREQUEST._serialized_start = 3680
    _OBSERVEPOSITIONSREQUEST._serialized_end = 3798
    _OBSERVEPOSITIONSRESPONSE._serialized_start = 3801
    _OBSERVEPOSITIONSRESPONSE._serialized_end = 3970
    _POSITIONSNAPSHOTPAGE._serialized_start = 3972
    _POSITIONSNAPSHOTPAGE._serialized_end = 4069
    _POSITIONUPDATES._serialized_start = 4071
    _POSITIONUPDATES._serialized_end = 4134
    _LEDGERENTRYFILTER._serialized_start = 4137
    _LEDGERENTRYFILTER._serialized_end = 4428
    _AGGREGATEDLEDGERENTRIES._serialized_start = 4431
    _AGGREGATEDLEDGERENTRIES._serialized_end = 4769
    _GROUPOPTIONS._serialized_start = 4772
    _GROUPOPTIONS._serialized_end = 4945
    _LISTLEDGERENTRIESREQUEST._serialized_start = 4948
    _LISTLEDGERENTRIESREQUEST._serialized_end = 5262
    _LISTLEDGERENTRIESRESPONSE._serialized_start = 5264
    _LISTLEDGERENTRIESRESPONSE._serialized_end = 5382
    _AGGREGATEDLEDGERENTRIESEDGE._serialized_start = 5384
    _AGGREGATEDLEDGERENTRIESEDGE._serialized_end = 5499
    _AGGREGATEDLEDGERENTRIESCONNECTION._serialized_start = 5502
    _AGGREGATEDLEDGERENTRIESCONNECTION._serialized_end = 5661
    _LISTBALANCECHANGESREQUEST._serialized_start = 5664
    _LISTBALANCECHANGESREQUEST._serialized_end = 5907
    _LISTBALANCECHANGESRESPONSE._serialized_start = 5909
    _LISTBALANCECHANGESRESPONSE._serialized_end = 6011
    _GETBALANCEHISTORYREQUEST._serialized_start = 6014
    _GETBALANCEHISTORYREQUEST._serialized_end = 6314
    _GETBALANCEHISTORYRESPONSE._serialized_start = 6316
    _GETBALANCEHISTORYRESPONSE._serialized_end = 6417
    _AGGREGATEDBALANCEEDGE._serialized_start = 6419
    _AGGREGATEDBALANCEEDGE._serialized_end = 6522
    _AGGREGATEDBALANCECONNECTION._serialized_start = 6525
    _AGGREGATEDBALANCECONNECTION._serialized_end = 6672
    _ACCOUNTFILTER._serialized_start = 6675
    _ACCOUNTFILTER._serialized_end = 6833
    _AGGREGATEDBALANCE._serialized_start = 6836
    _AGGREGATEDBALANCE._serialized_end = 7125
    _OBSERVEMARKETSDEPTHREQUEST._serialized_start = 7127
    _OBSERVEMARKETSDEPTHREQUEST._serialized_end = 7186
    _OBSERVEMARKETSDEPTHRESPONSE._serialized_start = 7188
    _OBSERVEMARKETSDEPTHRESPONSE._serialized_end = 7271
    _OBSERVEMARKETSDEPTHUPDATESREQUEST._serialized_start = 7273
    _OBSERVEMARKETSDEPTHUPDATESREQUEST._serialized_end = 7339
    _OBSERVEMARKETSDEPTHUPDATESRESPONSE._serialized_start = 7341
    _OBSERVEMARKETSDEPTHUPDATESRESPONSE._serialized_end = 7426
    _OBSERVEMARKETSDATAREQUEST._serialized_start = 7428
    _OBSERVEMARKETSDATAREQUEST._serialized_end = 7486
    _OBSERVEMARKETSDATARESPONSE._serialized_start = 7488
    _OBSERVEMARKETSDATARESPONSE._serialized_end = 7567
    _GETLATESTMARKETDEPTHREQUEST._serialized_start = 7569
    _GETLATESTMARKETDEPTHREQUEST._serialized_end = 7675
    _GETLATESTMARKETDEPTHRESPONSE._serialized_start = 7678
    _GETLATESTMARKETDEPTHRESPONSE._serialized_end = 7896
    _LISTLATESTMARKETDATAREQUEST._serialized_start = 7898
    _LISTLATESTMARKETDATAREQUEST._serialized_end = 7927
    _LISTLATESTMARKETDATARESPONSE._serialized_start = 7929
    _LISTLATESTMARKETDATARESPONSE._serialized_end = 8012
    _GETLATESTMARKETDATAREQUEST._serialized_start = 8014
    _GETLATESTMARKETDATAREQUEST._serialized_end = 8071
    _GETLATESTMARKETDATARESPONSE._serialized_start = 8073
    _GETLATESTMARKETDATARESPONSE._serialized_end = 8153
    _GETMARKETDATAHISTORYBYIDREQUEST._serialized_start = 8156
    _GETMARKETDATAHISTORYBYIDREQUEST._serialized_end = 8536
    _GETMARKETDATAHISTORYBYIDRESPONSE._serialized_start = 8538
    _GETMARKETDATAHISTORYBYIDRESPONSE._serialized_end = 8644
    _MARKETDATAEDGE._serialized_start = 8646
    _MARKETDATAEDGE._serialized_end = 8724
    _MARKETDATACONNECTION._serialized_start = 8727
    _MARKETDATACONNECTION._serialized_end = 8860
    _MARKETSDATASUBSCRIBEREQUEST._serialized_start = 8862
    _MARKETSDATASUBSCRIBEREQUEST._serialized_end = 8920
    _MARKETSDATASUBSCRIBERESPONSE._serialized_start = 8922
    _MARKETSDATASUBSCRIBERESPONSE._serialized_end = 9003
    _LISTTRANSFERSREQUEST._serialized_start = 9006
    _LISTTRANSFERSREQUEST._serialized_end = 9215
    _LISTTRANSFERSRESPONSE._serialized_start = 9217
    _LISTTRANSFERSRESPONSE._serialized_end = 9307
    _TRANSFEREDGE._serialized_start = 9309
    _TRANSFEREDGE._serialized_end = 9393
    _TRANSFERCONNECTION._serialized_start = 9396
    _TRANSFERCONNECTION._serialized_end = 9525
    _GETNETWORKLIMITSREQUEST._serialized_start = 9527
    _GETNETWORKLIMITSREQUEST._serialized_end = 9552
    _GETNETWORKLIMITSRESPONSE._serialized_start = 9554
    _GETNETWORKLIMITSRESPONSE._serialized_end = 9625
    _LISTCANDLEINTERVALSREQUEST._serialized_start = 9627
    _LISTCANDLEINTERVALSREQUEST._serialized_end = 9684
    _INTERVALTOCANDLEID._serialized_start = 9686
    _INTERVALTOCANDLEID._serialized_end = 9763
    _LISTCANDLEINTERVALSRESPONSE._serialized_start = 9765
    _LISTCANDLEINTERVALSRESPONSE._serialized_end = 9882
    _CANDLE._serialized_start = 9885
    _CANDLE._serialized_end = 10052
    _OBSERVECANDLEDATAREQUEST._serialized_start = 10054
    _OBSERVECANDLEDATAREQUEST._serialized_end = 10109
    _OBSERVECANDLEDATARESPONSE._serialized_start = 10111
    _OBSERVECANDLEDATARESPONSE._serialized_end = 10187
    _LISTCANDLEDATAREQUEST._serialized_start = 10190
    _LISTCANDLEDATAREQUEST._serialized_end = 10441
    _LISTCANDLEDATARESPONSE._serialized_start = 10443
    _LISTCANDLEDATARESPONSE._serialized_end = 10532
    _CANDLEEDGE._serialized_start = 10534
    _CANDLEEDGE._serialized_end = 10615
    _CANDLEDATACONNECTION._serialized_start = 10618
    _CANDLEDATACONNECTION._serialized_end = 10747
    _LISTVOTESREQUEST._serialized_start = 10750
    _LISTVOTESREQUEST._serialized_end = 10948
    _LISTVOTESRESPONSE._serialized_start = 10950
    _LISTVOTESRESPONSE._serialized_end = 11024
    _VOTEEDGE._serialized_start = 11026
    _VOTEEDGE._serialized_end = 11092
    _VOTECONNECTION._serialized_start = 11094
    _VOTECONNECTION._serialized_end = 11215
    _OBSERVEVOTESREQUEST._serialized_start = 11217
    _OBSERVEVOTESREQUEST._serialized_end = 11337
    _OBSERVEVOTESRESPONSE._serialized_start = 11339
    _OBSERVEVOTESRESPONSE._serialized_end = 11393
    _LISTERC20MULTISIGSIGNERADDEDBUNDLESREQUEST._serialized_start = 11396
    _LISTERC20MULTISIGSIGNERADDEDBUNDLESREQUEST._serialized_end = 11585
    _LISTERC20MULTISIGSIGNERADDEDBUNDLESRESPONSE._serialized_start = 11587
    _LISTERC20MULTISIGSIGNERADDEDBUNDLESRESPONSE._serialized_end = 11711
    _ERC20MULTISIGSIGNERADDEDEDGE._serialized_start = 11713
    _ERC20MULTISIGSIGNERADDEDEDGE._serialized_end = 11829
    _ERC20MULTISIGSIGNERADDEDBUNDLEEDGE._serialized_start = 11832
    _ERC20MULTISIGSIGNERADDEDBUNDLEEDGE._serialized_end = 11961
    _ERC20MULTISIGSIGNERADDEDCONNECTION._serialized_start = 11964
    _ERC20MULTISIGSIGNERADDEDCONNECTION._serialized_end = 12131
    _ERC20MULTISIGSIGNERADDEDBUNDLE._serialized_start = 12134
    _ERC20MULTISIGSIGNERADDEDBUNDLE._serialized_end = 12340
    _LISTERC20MULTISIGSIGNERREMOVEDBUNDLESREQUEST._serialized_start = 12343
    _LISTERC20MULTISIGSIGNERREMOVEDBUNDLESREQUEST._serialized_end = 12534
    _LISTERC20MULTISIGSIGNERREMOVEDBUNDLESRESPONSE._serialized_start = 12537
    _LISTERC20MULTISIGSIGNERREMOVEDBUNDLESRESPONSE._serialized_end = 12665
    _ERC20MULTISIGSIGNERREMOVEDEDGE._serialized_start = 12667
    _ERC20MULTISIGSIGNERREMOVEDEDGE._serialized_end = 12787
    _ERC20MULTISIGSIGNERREMOVEDBUNDLEEDGE._serialized_start = 12790
    _ERC20MULTISIGSIGNERREMOVEDBUNDLEEDGE._serialized_end = 12923
    _ERC20MULTISIGSIGNERREMOVEDCONNECTION._serialized_start = 12926
    _ERC20MULTISIGSIGNERREMOVEDCONNECTION._serialized_end = 13097
    _ERC20MULTISIGSIGNERREMOVEDBUNDLE._serialized_start = 13100
    _ERC20MULTISIGSIGNERREMOVEDBUNDLE._serialized_end = 13308
    _GETERC20LISTASSETBUNDLEREQUEST._serialized_start = 13310
    _GETERC20LISTASSETBUNDLEREQUEST._serialized_end = 13369
    _GETERC20LISTASSETBUNDLERESPONSE._serialized_start = 13372
    _GETERC20LISTASSETBUNDLERESPONSE._serialized_end = 13530
    _GETERC20SETASSETLIMITSBUNDLEREQUEST._serialized_start = 13532
    _GETERC20SETASSETLIMITSBUNDLEREQUEST._serialized_end = 13602
    _GETERC20SETASSETLIMITSBUNDLERESPONSE._serialized_start = 13605
    _GETERC20SETASSETLIMITSBUNDLERESPONSE._serialized_end = 13837
    _GETERC20WITHDRAWALAPPROVALREQUEST._serialized_start = 13839
    _GETERC20WITHDRAWALAPPROVALREQUEST._serialized_end = 13911
    _GETERC20WITHDRAWALAPPROVALRESPONSE._serialized_start = 13914
    _GETERC20WITHDRAWALAPPROVALRESPONSE._serialized_end = 14154
    _GETLASTTRADEREQUEST._serialized_start = 14156
    _GETLASTTRADEREQUEST._serialized_end = 14206
    _GETLASTTRADERESPONSE._serialized_start = 14208
    _GETLASTTRADERESPONSE._serialized_end = 14265
    _LISTTRADESREQUEST._serialized_start = 14268
    _LISTTRADESREQUEST._serialized_end = 14585
    _LISTTRADESRESPONSE._serialized_start = 14587
    _LISTTRADESRESPONSE._serialized_end = 14665
    _TRADECONNECTION._serialized_start = 14667
    _TRADECONNECTION._serialized_end = 14790
    _TRADEEDGE._serialized_start = 14792
    _TRADEEDGE._serialized_end = 14860
    _OBSERVETRADESREQUEST._serialized_start = 14862
    _OBSERVETRADESREQUEST._serialized_end = 14977
    _OBSERVETRADESRESPONSE._serialized_start = 14979
    _OBSERVETRADESRESPONSE._serialized_end = 15039
    _GETORACLESPECREQUEST._serialized_start = 15041
    _GETORACLESPECREQUEST._serialized_end = 15101
    _GETORACLESPECRESPONSE._serialized_start = 15103
    _GETORACLESPECRESPONSE._serialized_end = 15177
    _LISTORACLESPECSREQUEST._serialized_start = 15179
    _LISTORACLESPECSREQUEST._serialized_end = 15284
    _LISTORACLESPECSRESPONSE._serialized_start = 15286
    _LISTORACLESPECSRESPONSE._serialized_end = 15386
    _LISTORACLEDATAREQUEST._serialized_start = 15389
    _LISTORACLEDATAREQUEST._serialized_end = 15555
    _LISTORACLEDATARESPONSE._serialized_start = 15557
    _LISTORACLEDATARESPONSE._serialized_end = 15653
    _ORACLESPECEDGE._serialized_start = 15655
    _ORACLESPECEDGE._serialized_end = 15733
    _ORACLESPECSCONNECTION._serialized_start = 15736
    _ORACLESPECSCONNECTION._serialized_end = 15870
    _ORACLEDATAEDGE._serialized_start = 15872
    _ORACLEDATAEDGE._serialized_end = 15950
    _ORACLEDATACONNECTION._serialized_start = 15953
    _ORACLEDATACONNECTION._serialized_end = 16086
    _GETMARKETREQUEST._serialized_start = 16088
    _GETMARKETREQUEST._serialized_end = 16135
    _GETMARKETRESPONSE._serialized_start = 16137
    _GETMARKETRESPONSE._serialized_end = 16194
    _LISTMARKETSREQUEST._serialized_start = 16196
    _LISTMARKETSREQUEST._serialized_end = 16297
    _LISTMARKETSRESPONSE._serialized_start = 16299
    _LISTMARKETSRESPONSE._serialized_end = 16381
    _MARKETEDGE._serialized_start = 16383
    _MARKETEDGE._serialized_end = 16453
    _MARKETCONNECTION._serialized_start = 16455
    _MARKETCONNECTION._serialized_end = 16580
    _GETPARTYREQUEST._serialized_start = 16582
    _GETPARTYREQUEST._serialized_end = 16626
    _GETPARTYRESPONSE._serialized_start = 16628
    _GETPARTYRESPONSE._serialized_end = 16681
    _LISTPARTIESREQUEST._serialized_start = 16683
    _LISTPARTIESREQUEST._serialized_end = 16791
    _LISTPARTIESRESPONSE._serialized_start = 16793
    _LISTPARTIESRESPONSE._serialized_end = 16874
    _PARTYEDGE._serialized_start = 16876
    _PARTYEDGE._serialized_end = 16944
    _PARTYCONNECTION._serialized_start = 16946
    _PARTYCONNECTION._serialized_end = 17069
    _ORDEREDGE._serialized_start = 17071
    _ORDEREDGE._serialized_end = 17139
    _LISTMARGINLEVELSREQUEST._serialized_start = 17142
    _LISTMARGINLEVELSREQUEST._serialized_end = 17284
    _LISTMARGINLEVELSRESPONSE._serialized_start = 17286
    _LISTMARGINLEVELSRESPONSE._serialized_end = 17384
    _OBSERVEMARGINLEVELSREQUEST._serialized_start = 17386
    _OBSERVEMARGINLEVELSREQUEST._serialized_end = 17489
    _OBSERVEMARGINLEVELSRESPONSE._serialized_start = 17491
    _OBSERVEMARGINLEVELSRESPONSE._serialized_end = 17577
    _ORDERCONNECTION._serialized_start = 17579
    _ORDERCONNECTION._serialized_end = 17702
    _MARGINEDGE._serialized_start = 17704
    _MARGINEDGE._serialized_end = 17780
    _MARGINCONNECTION._serialized_start = 17782
    _MARGINCONNECTION._serialized_end = 17907
    _LISTREWARDSREQUEST._serialized_start = 17910
    _LISTREWARDSREQUEST._serialized_end = 18083
    _LISTREWARDSRESPONSE._serialized_start = 18085
    _LISTREWARDSRESPONSE._serialized_end = 18168
    _REWARDEDGE._serialized_start = 18170
    _REWARDEDGE._serialized_end = 18240
    _REWARDSCONNECTION._serialized_start = 18242
    _REWARDSCONNECTION._serialized_end = 18368
    _LISTREWARDSUMMARIESREQUEST._serialized_start = 18371
    _LISTREWARDSUMMARIESREQUEST._serialized_end = 18570
    _LISTREWARDSUMMARIESRESPONSE._serialized_start = 18572
    _LISTREWARDSUMMARIESRESPONSE._serialized_end = 18652
    _OBSERVEREWARDSREQUEST._serialized_start = 18654
    _OBSERVEREWARDSREQUEST._serialized_end = 18767
    _OBSERVEREWARDSRESPONSE._serialized_start = 18769
    _OBSERVEREWARDSRESPONSE._serialized_end = 18831
    _GETDEPOSITREQUEST._serialized_start = 18833
    _GETDEPOSITREQUEST._serialized_end = 18868
    _GETDEPOSITRESPONSE._serialized_start = 18870
    _GETDEPOSITRESPONSE._serialized_end = 18931
    _LISTDEPOSITSREQUEST._serialized_start = 18934
    _LISTDEPOSITSREQUEST._serialized_end = 19142
    _LISTDEPOSITSRESPONSE._serialized_start = 19144
    _LISTDEPOSITSRESPONSE._serialized_end = 19231
    _DEPOSITEDGE._serialized_start = 19233
    _DEPOSITEDGE._serialized_end = 19305
    _DEPOSITSCONNECTION._serialized_start = 19308
    _DEPOSITSCONNECTION._serialized_end = 19436
    _GETWITHDRAWALREQUEST._serialized_start = 19438
    _GETWITHDRAWALREQUEST._serialized_end = 19476
    _GETWITHDRAWALRESPONSE._serialized_start = 19478
    _GETWITHDRAWALRESPONSE._serialized_end = 19551
    _LISTWITHDRAWALSREQUEST._serialized_start = 19554
    _LISTWITHDRAWALSREQUEST._serialized_end = 19765
    _LISTWITHDRAWALSRESPONSE._serialized_start = 19767
    _LISTWITHDRAWALSRESPONSE._serialized_end = 19866
    _WITHDRAWALEDGE._serialized_start = 19868
    _WITHDRAWALEDGE._serialized_end = 19946
    _WITHDRAWALSCONNECTION._serialized_start = 19949
    _WITHDRAWALSCONNECTION._serialized_end = 20083
    _GETASSETREQUEST._serialized_start = 20085
    _GETASSETREQUEST._serialized_end = 20129
    _GETASSETRESPONSE._serialized_start = 20131
    _GETASSETRESPONSE._serialized_end = 20184
    _LISTASSETSREQUEST._serialized_start = 20187
    _LISTASSETSREQUEST._serialized_end = 20332
    _LISTASSETSRESPONSE._serialized_start = 20334
    _LISTASSETSRESPONSE._serialized_end = 20413
    _ASSETEDGE._serialized_start = 20415
    _ASSETEDGE._serialized_end = 20483
    _ASSETSCONNECTION._serialized_start = 20485
    _ASSETSCONNECTION._serialized_end = 20609
    _LISTLIQUIDITYPROVISIONSREQUEST._serialized_start = 20612
    _LISTLIQUIDITYPROVISIONSREQUEST._serialized_end = 20867
    _LISTLIQUIDITYPROVISIONSRESPONSE._serialized_start = 20870
    _LISTLIQUIDITYPROVISIONSRESPONSE._serialized_end = 21002
    _LIQUIDITYPROVISIONSEDGE._serialized_start = 21004
    _LIQUIDITYPROVISIONSEDGE._serialized_end = 21099
    _LIQUIDITYPROVISIONSCONNECTION._serialized_start = 21102
    _LIQUIDITYPROVISIONSCONNECTION._serialized_end = 21253
    _OBSERVELIQUIDITYPROVISIONSREQUEST._serialized_start = 21256
    _OBSERVELIQUIDITYPROVISIONSREQUEST._serialized_end = 21384
    _OBSERVELIQUIDITYPROVISIONSRESPONSE._serialized_start = 21386
    _OBSERVELIQUIDITYPROVISIONSRESPONSE._serialized_end = 21499
    _GETGOVERNANCEDATAREQUEST._serialized_start = 21502
    _GETGOVERNANCEDATAREQUEST._serialized_end = 21631
    _GETGOVERNANCEDATARESPONSE._serialized_start = 21633
    _GETGOVERNANCEDATARESPONSE._serialized_end = 21702
    _LISTGOVERNANCEDATAREQUEST._serialized_start = 21705
    _LISTGOVERNANCEDATAREQUEST._serialized_end = 22339
    _LISTGOVERNANCEDATAREQUEST_TYPE._serialized_start = 22059
    _LISTGOVERNANCEDATAREQUEST_TYPE._serialized_end = 22242
    _LISTGOVERNANCEDATARESPONSE._serialized_start = 22341
    _LISTGOVERNANCEDATARESPONSE._serialized_end = 22444
    _GOVERNANCEDATAEDGE._serialized_start = 22446
    _GOVERNANCEDATAEDGE._serialized_end = 22532
    _GOVERNANCEDATACONNECTION._serialized_start = 22535
    _GOVERNANCEDATACONNECTION._serialized_end = 22676
    _OBSERVEGOVERNANCEREQUEST._serialized_start = 22678
    _OBSERVEGOVERNANCEREQUEST._serialized_end = 22749
    _OBSERVEGOVERNANCERESPONSE._serialized_start = 22751
    _OBSERVEGOVERNANCERESPONSE._serialized_end = 22820
    _LISTDELEGATIONSREQUEST._serialized_start = 22823
    _LISTDELEGATIONSREQUEST._serialized_end = 23060
    _LISTDELEGATIONSRESPONSE._serialized_start = 23062
    _LISTDELEGATIONSRESPONSE._serialized_end = 23161
    _DELEGATIONEDGE._serialized_start = 23163
    _DELEGATIONEDGE._serialized_end = 23241
    _DELEGATIONSCONNECTION._serialized_start = 23244
    _DELEGATIONSCONNECTION._serialized_end = 23378
    _OBSERVEDELEGATIONSREQUEST._serialized_start = 23380
    _OBSERVEDELEGATIONSREQUEST._serialized_end = 23494
    _OBSERVEDELEGATIONSRESPONSE._serialized_start = 23496
    _OBSERVEDELEGATIONSRESPONSE._serialized_end = 23574
    _GETNETWORKDATAREQUEST._serialized_start = 23576
    _GETNETWORKDATAREQUEST._serialized_end = 23599
    _GETNETWORKDATARESPONSE._serialized_start = 23601
    _GETNETWORKDATARESPONSE._serialized_end = 23670
    _GETNODEREQUEST._serialized_start = 23672
    _GETNODEREQUEST._serialized_end = 23704
    _GETNODERESPONSE._serialized_start = 23706
    _GETNODERESPONSE._serialized_end = 23755
    _LISTNODESREQUEST._serialized_start = 23758
    _LISTNODESREQUEST._serialized_end = 23905
    _LISTNODESRESPONSE._serialized_start = 23907
    _LISTNODESRESPONSE._serialized_end = 23982
    _NODEEDGE._serialized_start = 23984
    _NODEEDGE._serialized_end = 24050
    _NODESCONNECTION._serialized_start = 24052
    _NODESCONNECTION._serialized_end = 24174
    _LISTNODESIGNATURESREQUEST._serialized_start = 24176
    _LISTNODESIGNATURESREQUEST._serialized_end = 24300
    _LISTNODESIGNATURESRESPONSE._serialized_start = 24302
    _LISTNODESIGNATURESRESPONSE._serialized_end = 24405
    _NODESIGNATUREEDGE._serialized_start = 24407
    _NODESIGNATUREEDGE._serialized_end = 24503
    _NODESIGNATURESCONNECTION._serialized_start = 24506
    _NODESIGNATURESCONNECTION._serialized_end = 24646
    _GETEPOCHREQUEST._serialized_start = 24648
    _GETEPOCHREQUEST._serialized_end = 24693
    _GETEPOCHRESPONSE._serialized_start = 24695
    _GETEPOCHRESPONSE._serialized_end = 24748
    _ESTIMATEFEEREQUEST._serialized_start = 24750
    _ESTIMATEFEEREQUEST._serialized_end = 24841
    _ESTIMATEFEERESPONSE._serialized_start = 24843
    _ESTIMATEFEERESPONSE._serialized_end = 24893
    _ESTIMATEMARGINREQUEST._serialized_start = 24896
    _ESTIMATEMARGINREQUEST._serialized_end = 25087
    _ESTIMATEMARGINRESPONSE._serialized_start = 25089
    _ESTIMATEMARGINRESPONSE._serialized_end = 25170
    _LISTNETWORKPARAMETERSREQUEST._serialized_start = 25172
    _LISTNETWORKPARAMETERSREQUEST._serialized_end = 25283
    _LISTNETWORKPARAMETERSRESPONSE._serialized_start = 25285
    _LISTNETWORKPARAMETERSRESPONSE._serialized_end = 25408
    _GETNETWORKPARAMETERREQUEST._serialized_start = 25410
    _GETNETWORKPARAMETERREQUEST._serialized_end = 25456
    _GETNETWORKPARAMETERRESPONSE._serialized_start = 25458
    _GETNETWORKPARAMETERRESPONSE._serialized_end = 25556
    _NETWORKPARAMETEREDGE._serialized_start = 25558
    _NETWORKPARAMETEREDGE._serialized_end = 25648
    _NETWORKPARAMETERCONNECTION._serialized_start = 25651
    _NETWORKPARAMETERCONNECTION._serialized_end = 25796
    _CHECKPOINT._serialized_start = 25798
    _CHECKPOINT._serialized_end = 25888
    _LISTCHECKPOINTSREQUEST._serialized_start = 25890
    _LISTCHECKPOINTSREQUEST._serialized_end = 25995
    _LISTCHECKPOINTSRESPONSE._serialized_start = 25997
    _LISTCHECKPOINTSRESPONSE._serialized_end = 26096
    _CHECKPOINTEDGE._serialized_start = 26098
    _CHECKPOINTEDGE._serialized_end = 26187
    _CHECKPOINTSCONNECTION._serialized_start = 26190
    _CHECKPOINTSCONNECTION._serialized_end = 26324
    _GETSTAKEREQUEST._serialized_start = 26326
    _GETSTAKEREQUEST._serialized_end = 26451
    _GETSTAKERESPONSE._serialized_start = 26454
    _GETSTAKERESPONSE._serialized_end = 26602
    _STAKELINKINGEDGE._serialized_start = 26604
    _STAKELINKINGEDGE._serialized_end = 26696
    _STAKESCONNECTION._serialized_start = 26699
    _STAKESCONNECTION._serialized_end = 26830
    _GETRISKFACTORSREQUEST._serialized_start = 26832
    _GETRISKFACTORSREQUEST._serialized_end = 26884
    _GETRISKFACTORSRESPONSE._serialized_start = 26886
    _GETRISKFACTORSRESPONSE._serialized_end = 26961
    _OBSERVEEVENTBUSREQUEST._serialized_start = 26964
    _OBSERVEEVENTBUSREQUEST._serialized_end = 27125
    _OBSERVEEVENTBUSRESPONSE._serialized_start = 27127
    _OBSERVEEVENTBUSRESPONSE._serialized_end = 27202
    _OBSERVELEDGERMOVEMENTSREQUEST._serialized_start = 27204
    _OBSERVELEDGERMOVEMENTSREQUEST._serialized_end = 27235
    _OBSERVELEDGERMOVEMENTSRESPONSE._serialized_start = 27237
    _OBSERVELEDGERMOVEMENTSRESPONSE._serialized_end = 27332
    _LISTKEYROTATIONSREQUEST._serialized_start = 27335
    _LISTKEYROTATIONSREQUEST._serialized_end = 27483
    _LISTKEYROTATIONSRESPONSE._serialized_start = 27485
    _LISTKEYROTATIONSRESPONSE._serialized_end = 27581
    _KEYROTATIONEDGE._serialized_start = 27583
    _KEYROTATIONEDGE._serialized_end = 27673
    _KEYROTATIONCONNECTION._serialized_start = 27676
    _KEYROTATIONCONNECTION._serialized_end = 27811
    _LISTETHEREUMKEYROTATIONSREQUEST._serialized_start = 27814
    _LISTETHEREUMKEYROTATIONSREQUEST._serialized_end = 27970
    _LISTETHEREUMKEYROTATIONSRESPONSE._serialized_start = 27972
    _LISTETHEREUMKEYROTATIONSRESPONSE._serialized_end = 28092
    _ETHEREUMKEYROTATIONSCONNECTION._serialized_start = 28095
    _ETHEREUMKEYROTATIONSCONNECTION._serialized_end = 28247
    _ETHEREUMKEYROTATIONEDGE._serialized_start = 28250
    _ETHEREUMKEYROTATIONEDGE._serialized_end = 28388
    _GETVEGATIMEREQUEST._serialized_start = 28390
    _GETVEGATIMEREQUEST._serialized_end = 28410
    _GETVEGATIMERESPONSE._serialized_start = 28412
    _GETVEGATIMERESPONSE._serialized_end = 28463
    _DATERANGE._serialized_start = 28466
    _DATERANGE._serialized_end = 28603
    _GETPROTOCOLUPGRADESTATUSREQUEST._serialized_start = 28605
    _GETPROTOCOLUPGRADESTATUSREQUEST._serialized_end = 28638
    _GETPROTOCOLUPGRADESTATUSRESPONSE._serialized_start = 28640
    _GETPROTOCOLUPGRADESTATUSRESPONSE._serialized_end = 28696
    _LISTPROTOCOLUPGRADEPROPOSALSREQUEST._serialized_start = 28699
    _LISTPROTOCOLUPGRADEPROPOSALSREQUEST._serialized_end = 28958
    _LISTPROTOCOLUPGRADEPROPOSALSRESPONSE._serialized_start = 28961
    _LISTPROTOCOLUPGRADEPROPOSALSRESPONSE._serialized_end = 29113
    _PROTOCOLUPGRADEPROPOSALCONNECTION._serialized_start = 29116
    _PROTOCOLUPGRADEPROPOSALCONNECTION._serialized_end = 29275
    _PROTOCOLUPGRADEPROPOSALEDGE._serialized_start = 29277
    _PROTOCOLUPGRADEPROPOSALEDGE._serialized_end = 29388
    _HISTORYSEGMENT._serialized_start = 29391
    _HISTORYSEGMENT._serialized_end = 29605
    _GETMOSTRECENTDEHISTORYSEGMENTREQUEST._serialized_start = 29607
    _GETMOSTRECENTDEHISTORYSEGMENTREQUEST._serialized_end = 29645
    _GETMOSTRECENTDEHISTORYSEGMENTRESPONSE._serialized_start = 29647
    _GETMOSTRECENTDEHISTORYSEGMENTRESPONSE._serialized_end = 29745
    _LISTALLDEHISTORYSEGMENTSREQUEST._serialized_start = 29747
    _LISTALLDEHISTORYSEGMENTSREQUEST._serialized_end = 29780
    _LISTALLDEHISTORYSEGMENTSRESPONSE._serialized_start = 29782
    _LISTALLDEHISTORYSEGMENTSRESPONSE._serialized_end = 29877
    _FETCHDEHISTORYSEGMENTREQUEST._serialized_start = 29879
    _FETCHDEHISTORYSEGMENTREQUEST._serialized_end = 29955
    _FETCHDEHISTORYSEGMENTRESPONSE._serialized_start = 29957
    _FETCHDEHISTORYSEGMENTRESPONSE._serialized_end = 30047
    _GETACTIVEDEHISTORYPEERADDRESSESREQUEST._serialized_start = 30049
    _GETACTIVEDEHISTORYPEERADDRESSESREQUEST._serialized_end = 30089
    _GETACTIVEDEHISTORYPEERADDRESSESRESPONSE._serialized_start = 30091
    _GETACTIVEDEHISTORYPEERADDRESSESRESPONSE._serialized_end = 30167
    _COPYHISTORYSEGMENTTOFILEREQUEST._serialized_start = 30169
    _COPYHISTORYSEGMENTTOFILEREQUEST._serialized_end = 30281
    _COPYHISTORYSEGMENTTOFILERESPONSE._serialized_start = 30283
    _COPYHISTORYSEGMENTTOFILERESPONSE._serialized_end = 30317
    _PINGREQUEST._serialized_start = 30319
    _PINGREQUEST._serialized_end = 30332
    _PINGRESPONSE._serialized_start = 30334
    _PINGRESPONSE._serialized_end = 30348
    _TRADINGDATASERVICE._serialized_start = 30879
    _TRADINGDATASERVICE._serialized_end = 39775
# @@protoc_insertion_point(module_scope)



from vega_sim.parameter_test.parameter.experiment import SingleParameterExperiment
from vega_sim.parameter_test.parameter.loggers import (
    ideal_market_maker_single_data_extraction,
    target_stake_additional_data,
    v1_ideal_mm_additional_data,
    tau_scaling_additional_data,
    limit_order_book,
)
from vega_sim.scenario.configurable_market.scenario import ConfigurableMarket
from vega_sim.scenario.curve_market_maker.scenario import CurveMarketMaker
from vega_sim.scenario.registry import IdealMarketMaker, IdealMarketMakerV2
from vega_sim.parameter_test.parameter.loggers import (
    BASE_IDEAL_MM_CSV_HEADERS,
    LOB_CSV_HEADERS,
)
from vega_sim.parameter_test.parameter.experiment import (
    FILE_PATTERN,
    FILE_PATTERN_LOB,
)
from vega_sim.scenario.common.utils.price_process import (
    Granularity,
    get_historic_price_series,
)

TARGET_STAKE_SCALING_FACTOR_IDEAL = SingleParameterExperiment(
    name="StakeTargetScaling",
    parameter_to_vary="market.stake.target.scalingFactor",
    values=["0.5", "5", "50"],
    scenario=IdealMarketMaker(
        num_steps=288,
        market_decimal=3,
        asset_decimal=5,
        market_position_decimal=2,
        spread=0.002,
        initial_asset_mint=1e8,
        lp_initial_mint=1e8,
        lp_commitamount=50000,
        initial_price=1123.11,
        sigma=0.1,
        kappa=50,
        lambda_val=10,
        q_upper=50,
        q_lower=-50,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                v1_ideal_mm_additional_data,
                tau_scaling_additional_data,
                target_stake_additional_data,
                limit_order_book,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
    data_extraction=[
        (FILE_PATTERN, BASE_IDEAL_MM_CSV_HEADERS),
        (FILE_PATTERN_LOB, LOB_CSV_HEADERS),
    ],
)

TAU_SCALING_FACTOR_IDEAL = SingleParameterExperiment(
    name="TauScaling",
    parameter_to_vary="market.liquidity.probabilityOfTrading.tau.scaling",
    values=["1", "10", "100"],
    scenario=IdealMarketMaker(
        num_steps=288,
        market_decimal=3,
        asset_decimal=5,
        market_position_decimal=2,
        spread=0.002,
        initial_asset_mint=1e8,
        lp_initial_mint=1e8,
        lp_commitamount=50000,
        initial_price=1123.11,
        sigma=0.1,
        kappa=50,
        lambda_val=10,
        q_upper=50,
        q_lower=-50,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                v1_ideal_mm_additional_data,
                tau_scaling_additional_data,
                target_stake_additional_data,
                limit_order_book,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
    data_extraction=[
        (FILE_PATTERN, BASE_IDEAL_MM_CSV_HEADERS),
        (FILE_PATTERN_LOB, LOB_CSV_HEADERS),
    ],
)

TARGET_STAKE_SCALING_FACTOR_IDEAL_v2 = SingleParameterExperiment(
    name="StakeTargetScaling_v2",
    parameter_to_vary="market.stake.target.scalingFactor",
    values=["0.5", "5", "50"],
    scenario=IdealMarketMakerV2(
        market_decimal=3,
        asset_decimal=5,
        market_position_decimal=2,
        initial_price=1123.11,
        spread=4,
        lp_commitamount=100000,
        initial_asset_mint=1e8,
        block_length_seconds=1,
        buy_intensity=10,
        sell_intensity=10,
        q_upper=50,
        q_lower=-50,
        kappa=50,
        sigma=0.1,
        num_steps=288,
        backgroundmarket_tick_spacing=0.002,
        backgroundmarket_number_levels_per_side=20,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                tau_scaling_additional_data,
                target_stake_additional_data,
                limit_order_book,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
    data_extraction=[
        (FILE_PATTERN, BASE_IDEAL_MM_CSV_HEADERS),
        (FILE_PATTERN_LOB, LOB_CSV_HEADERS),
    ],
)

TAU_SCALING_FACTOR_IDEAL_v2 = SingleParameterExperiment(
    name="TauScaling_v2",
    parameter_to_vary="market.liquidity.probabilityOfTrading.tau.scaling",
    values=["1", "10", "100"],
    scenario=IdealMarketMakerV2(
        market_decimal=3,
        asset_decimal=5,
        market_position_decimal=2,
        initial_price=1123.11,
        spread=4,
        lp_commitamount=100000,
        initial_asset_mint=1e8,
        block_length_seconds=1,
        buy_intensity=10,
        sell_intensity=10,
        q_upper=50,
        q_lower=-50,
        kappa=50,
        sigma=0.1,
        num_steps=288,
        backgroundmarket_tick_spacing=0.002,
        backgroundmarket_number_levels_per_side=20,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                tau_scaling_additional_data,
                target_stake_additional_data,
                limit_order_book,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
    data_extraction=[
        (FILE_PATTERN, BASE_IDEAL_MM_CSV_HEADERS),
        (FILE_PATTERN_LOB, LOB_CSV_HEADERS),
    ],
)

BOND_PENALTY_FACTOR_IDEAL_v2 = SingleParameterExperiment(
    name="BondPenalty_v2",
    parameter_to_vary="market.liquidity.bondPenaltyParameter",
    values=["0.0", "0.5", "1.0"],
    scenario=IdealMarketMakerV2(
        market_decimal=3,
        asset_decimal=5,
        market_position_decimal=2,
        initial_price=1123.11,
        spread=0.002,
        lp_commitamount=20000,
        block_length_seconds=1,
        buy_intensity=10,
        sell_intensity=10,
        q_upper=50,
        q_lower=-50,
        kappa=50,
        sigma=0.5,
        num_steps=72,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                tau_scaling_additional_data,
                target_stake_additional_data,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
)

TAU_SCALING_FACTOR_IDEAL_CURVE = SingleParameterExperiment(
    name="TauScaling_Curve",
    parameter_to_vary="market.liquidity.probabilityOfTrading.tau.scaling",
    values=["1", "10", "100"],
    scenario=CurveMarketMaker(
        market_name="ETH",
        asset_name="USD",
        num_steps=290,
        market_decimal=2,
        asset_decimal=4,
        market_position_decimal=4,
        # price_process_fn=lambda: get_historic_price_series(
        #     product_id="ETH-USD", granularity=Granularity.HOUR
        # ).values,
        initial_price=1500,
        lp_commitamount=250_000,
        initial_asset_mint=10_000_000,
        # step_length_seconds=60,
        # step_length_seconds=Granularity.HOUR.value,
        block_length_seconds=1,
        buy_intensity=100,
        sell_intensity=100,
        q_upper=30,
        q_lower=-30,
        market_maker_curve_kappa=0.2,
        market_maker_assumed_market_kappa=0.2,
        sensitive_price_taker_half_life=20,
        opening_auction_trade_amount=0.0001,
        market_order_trader_base_order_size=0.01,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                tau_scaling_additional_data,
                target_stake_additional_data,
                limit_order_book,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
    data_extraction=[
        (FILE_PATTERN, BASE_IDEAL_MM_CSV_HEADERS),
        (FILE_PATTERN_LOB, LOB_CSV_HEADERS),
    ],
)

MARKET_PARAMETER_DEMO = SingleParameterExperiment(
    name="MarketParameterDemo",
    parameter_to_vary=(
        "liquidity_monitoring_parameters.target_stake_parameters.scaling_factor"
    ),
    values=[1, 10, 100],
    scenario=ConfigurableMarket(
        market_name="RESEARCH: Ethereum:USD Q3 (Daily)",
        market_code="ETH:USD",
        asset_name="tUSD",
        asset_dp=18,
        num_steps=60,
        state_extraction_fn=ideal_market_maker_single_data_extraction(
            additional_data_fns=[
                tau_scaling_additional_data,
                target_stake_additional_data,
                limit_order_book,
            ]
        ),
    ),
    runs_per_scenario=2,
    additional_parameters_to_set=[
        ("market.liquidity.targetstake.triggering.ratio", "1")
    ],
    data_extraction=[
        (FILE_PATTERN, BASE_IDEAL_MM_CSV_HEADERS),
        (FILE_PATTERN_LOB, LOB_CSV_HEADERS),
    ],
    market_parameter=True,
)


CONFIGS = [
    TARGET_STAKE_SCALING_FACTOR_IDEAL,
    TAU_SCALING_FACTOR_IDEAL,
    TAU_SCALING_FACTOR_IDEAL_v2,
    TARGET_STAKE_SCALING_FACTOR_IDEAL_v2,
    BOND_PENALTY_FACTOR_IDEAL_v2,
    TAU_SCALING_FACTOR_IDEAL_CURVE,
    MARKET_PARAMETER_DEMO,
]



from . import core_pb2 as core
from . import core_pb2_grpc as core_grpc
from . import corestate_pb2 as corestate
from . import corestate_pb2_grpc as corestate_grpc

__all__ = [
    "core",
    "core_grpc",
    "corestate",
    "corestate_grpc",
]
